@@ -87,6 +87,11 @@ EABContactDisplayMode
 		eab_contact_display_get_mode	(EABContactDisplay *display);
 void		eab_contact_display_set_mode	(EABContactDisplay *display,
 						 EABContactDisplayMode mode);
+GtkOrientation	eab_contact_display_get_orientation
+						(EABContactDisplay *display);
+void		eab_contact_display_set_orientation
+						(EABContactDisplay *display,
+						 GtkOrientation orientation);
 
 G_END_DECLS
 
