@@ -49,8 +49,6 @@
 #include "config-data.h"
 #include "util.h"
 
-#define d(x)
-
 /* The dialog with alarm nofications */
 static AlarmNotificationsDialog *alarm_notifications_dialog = NULL;
 
@@ -125,19 +123,32 @@ typedef struct {
 static gpointer midnight_refresh_id = NULL;
 static time_t midnight = 0;
 
-static void
-remove_client_alarms (ClientAlarms *ca);
-static void display_notification (time_t trigger, CompQueuedAlarms *cqa,
-				  gpointer alarm_id, gboolean use_description);
-static void audio_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id);
-static void mail_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id);
-static void procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id);
+static void	remove_client_alarms		(ClientAlarms *ca);
+static void	display_notification		(time_t trigger,
+						 CompQueuedAlarms *cqa,
+						 gpointer alarm_id,
+						 gboolean use_description);
+static void	audio_notification		(time_t trigger,
+						 CompQueuedAlarms *cqa,
+						 gpointer alarm_id);
+static void	mail_notification		(time_t trigger,
+						 CompQueuedAlarms *cqa,
+						 gpointer alarm_id);
+static void	procedure_notification		(time_t trigger,
+						 CompQueuedAlarms *cqa,
+						 gpointer alarm_id);
 #ifdef HAVE_LIBNOTIFY
-static void popup_notification (time_t trigger, CompQueuedAlarms *cqa,
-				  gpointer alarm_id, gboolean use_description);
+static void	popup_notification		(time_t trigger,
+						 CompQueuedAlarms *cqa,
+						 gpointer alarm_id,
+						 gboolean use_description);
 #endif
-static void query_objects_changed_cb (ECal *client, GList *objects, gpointer data);
-static void query_objects_removed_cb (ECal *client, GList *objects, gpointer data);
+static void	query_objects_changed_cb	(ECal *client,
+						 GList *objects,
+						 gpointer data);
+static void	query_objects_removed_cb	(ECal *client,
+						 GList *objects,
+						 gpointer data);
 
 static void update_cqa (CompQueuedAlarms *cqa, ECalComponent *comp);
 static void update_qa (ECalComponentAlarms *alarms, QueuedAlarm *qa);
@@ -187,23 +198,30 @@ message_push (Message *msg)
  * use a static ring-buffer so we can call this twice
  * in a printf without getting nonsense results.
  */
-d (#define DEBUGGING_ON)
-#ifdef DEBUGGING_ON
 static const gchar *
 e_ctime (const time_t *timep)
 {
-  static gchar *buffer[4] = { 0, };
-  static gint next = 0;
-  const gchar *ret;
+	static gchar *buffer[4] = { 0, };
+	static gint next = 0;
+	const gchar *ret;
 
-  g_free (buffer[next]);
-  ret = buffer[next++] = g_strdup (ctime (timep));
-  if (next >= G_N_ELEMENTS (buffer))
-	next = 0;
+	g_free (buffer[next]);
+	ret = buffer[next++] = g_strdup (ctime (timep));
+	if (buffer[next - 1] && *buffer[next - 1]) {
+		gint len = strlen (buffer[next - 1]);
+		while (len > 0 && (buffer[next - 1][len - 1] == '\n' ||
+			buffer[next - 1][len - 1] == '\r' ||
+			g_ascii_isspace (buffer[next - 1][len - 1])))
+			len--;
 
-  return ret;
+		buffer[next - 1][len - 1] = 0;
+	}
+
+	if (next >= G_N_ELEMENTS (buffer))
+		next = 0;
+
+	return ret;
 }
-#endif
 
 /* Queues an alarm trigger for midnight so that we can load the next day's worth
  * of alarms.
@@ -221,11 +239,11 @@ queue_midnight_refresh (void)
 	zone = config_data_get_timezone ();
 	midnight = time_day_end_with_zone (time (NULL), zone);
 
-	d(printf("%s:%d (queue_midnight_refresh) - Refresh at %s \n",__FILE__, __LINE__, e_ctime(&midnight)));
+	debug (("Refresh at %s", e_ctime (&midnight)));
 
 	midnight_refresh_id = alarm_add (midnight, midnight_refresh_cb, NULL, NULL);
 	if (!midnight_refresh_id) {
-		 d(printf("%s:%d (queue_midnight_refresh) - Could not setup the midnight refresh alarm\n",__FILE__, __LINE__));
+		debug (("Could not setup the midnight refresh alarm"));
 		/* FIXME: what to do? */
 	}
 }
@@ -236,7 +254,7 @@ add_client_alarms_cb (gpointer key, gpointer value, gpointer data)
 {
 	ClientAlarms *ca = (ClientAlarms *) value;
 
-	d(printf("%s:%d (add_client_alarms_cb) - Adding %p\n",__FILE__, __LINE__, ca));
+	debug (("Adding %p", ca));
 
 	load_alarms_for_today (ca);
 }
@@ -250,14 +268,14 @@ struct _midnight_refresh_msg {
 static void
 midnight_refresh_async (struct _midnight_refresh_msg *msg)
 {
-	d(printf("%s:%d (midnight_refresh_async) \n",__FILE__, __LINE__));
+	debug (("..."));
 
 	/* Re-load the alarms for all clients */
 	g_hash_table_foreach (client_alarms_hash, add_client_alarms_cb, NULL);
 
 	/* Re-schedule the midnight update */
 	if (msg->remove && midnight_refresh_id != NULL) {
-		d(printf("%s:%d (midnight_refresh_async) - Reschedule the midnight update \n",__FILE__, __LINE__));
+		debug (("Reschedule the midnight update"));
 		alarm_remove (midnight_refresh_id);
 		midnight_refresh_id = NULL;
 	}
@@ -315,7 +333,7 @@ remove_queued_alarm (CompQueuedAlarms *cqa, gpointer alarm_id,
 	QueuedAlarm *qa=NULL;
 	GSList *l;
 
-	d(printf("%s:%d (remove_queued_alarm) \n",__FILE__, __LINE__));
+	debug (("..."));
 
 	for (l = cqa->queued_alarms; l; l = l->next) {
 		qa = l->data;
@@ -344,7 +362,7 @@ remove_queued_alarm (CompQueuedAlarms *cqa, gpointer alarm_id,
 	if (cqa->queued_alarms != NULL)
 		return FALSE;
 
-	d(printf("%s:%d (remove_queued_alarm) - Last Component. Removing CQA- Free=%d\n",__FILE__, __LINE__, free_object));
+	debug (("Last Component. Removing CQA- Free=%d", free_object));
 	if (free_object) {
 		cqa->id = NULL;
 		cqa->parent_client = NULL;
@@ -361,9 +379,10 @@ remove_queued_alarm (CompQueuedAlarms *cqa, gpointer alarm_id,
 /**
  * has_known_notification:
  * Test for notification method and returns if it knows it or not.
- * @param comp Component with an alarm.
- * @param alarm_uid ID of the alarm in the comp to test.
- * @return TRUE when we know the notification type, FALSE otherwise.
+ * @comp: Component with an alarm.
+ * @alarm_uid: ID of the alarm in the comp to test.
+ *
+ * Returns: %TRUE when we know the notification type, %FALSE otherwise.
  */
 static gboolean
 has_known_notification (ECalComponent *comp, const gchar *alarm_uid)
@@ -407,7 +426,7 @@ alarm_trigger_cb (gpointer alarm_id, time_t trigger, gpointer data)
 	comp = cqa->alarms->comp;
 
 	config_data_set_last_notification_time (cqa->parent_client->client, trigger);
-	d(printf("%s:%d (alarm_trigger_cb) - Setting Last notification time to %s\n",__FILE__, __LINE__, ctime (&trigger)));
+	debug (("Setting Last notification time to %s", e_ctime (&trigger)));
 
 	qa = lookup_queued_alarm (cqa, alarm_id);
 	if (!qa)
@@ -449,7 +468,7 @@ alarm_trigger_cb (gpointer alarm_id, time_t trigger, gpointer data)
 	default:
 		g_return_if_reached ();
 	}
-	d(printf("%s:%d (alarm_trigger_cb) - Notification sent:%d\n",__FILE__, __LINE__, action));
+	debug (("Notification sent: %d", action));
 }
 
 /* Adds the alarms in a ECalComponentAlarms structure to the alarms queued for a
@@ -464,7 +483,7 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 
 	/* No alarms? */
 	if (alarms == NULL || alarms->alarms == NULL) {
-		d(printf("%s:%d (add_component_alarms) - No alarms to add\n",__FILE__, __LINE__));
+		debug (("No alarms to add"));
 		if (alarms)
 			e_cal_component_alarms_free (alarms);
 		return;
@@ -476,26 +495,22 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 	cqa->expecting_update = FALSE;
 
 	cqa->queued_alarms = NULL;
-	d(printf("%s:%d (add_component_alarms) - Creating CQA %p\n",__FILE__, __LINE__, cqa));
+	debug (("Creating CQA %p", cqa));
 
 	for (l = alarms->alarms; l; l = l->next) {
 		ECalComponentAlarmInstance *instance;
 		gpointer alarm_id;
 		QueuedAlarm *qa;
-		d (time_t tnow = time (NULL));
 
 		instance = l->data;
 
-		if (!has_known_notification (cqa->alarms->comp, instance->auid)) {
-			g_debug ("Could not recognize alarm's notification type, discarding.");
+		if (!has_known_notification (cqa->alarms->comp, instance->auid))
 			continue;
-		}
 
-		alarm_id = alarm_add (instance->trigger, alarm_trigger_cb, cqa, NULL);
-		if (!alarm_id) {
-			d(printf("%s:%d (add_component_alarms) - Could not schedule a trigger for %s. Discarding \n",__FILE__, __LINE__, e_ctime(&(instance->trigger))));
+		alarm_id = alarm_add (
+			instance->trigger, alarm_trigger_cb, cqa, NULL);
+		if (!alarm_id)
 			continue;
-		}
 
 		qa = g_new (QueuedAlarm, 1);
 		qa->alarm_id = alarm_id;
@@ -504,7 +519,6 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 		qa->snooze = FALSE;
 
 		cqa->queued_alarms = g_slist_prepend (cqa->queued_alarms, qa);
-		d(printf("%s:%d (add_component_alarms) - Adding alarm %p %p at %s %s\n",__FILE__, __LINE__, qa, alarm_id, ctime (&(instance->trigger)), e_ctime(&tnow)));
 	}
 
 	id = e_cal_component_get_id (alarms->comp);
@@ -513,14 +527,14 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 	if (cqa->queued_alarms == NULL) {
 		e_cal_component_alarms_free (cqa->alarms);
 		cqa->alarms = NULL;
-		d(printf("%s:%d (add_component_alarms) - Failed to add all : %p\n",__FILE__, __LINE__, cqa));
+		debug (("Failed to add all : %p", cqa));
 		g_free (cqa);
 		return;
 	}
 
 	cqa->queued_alarms = g_slist_reverse (cqa->queued_alarms);
 	cqa->id = id;
-	d(printf("%s:%d (add_component_alarms) - Alarm added for %s\n",__FILE__, __LINE__, id->uid));
+	debug (("Alarm added for %s", id->uid));
 	g_hash_table_insert (ca->uid_alarms_hash, cqa->id, cqa);
 }
 
@@ -530,7 +544,7 @@ load_alarms (ClientAlarms *ca, time_t start, time_t end)
 {
 	gchar *str_query, *iso_start, *iso_end;
 
-	d(printf("%s:%d (load_alarms) \n",__FILE__, __LINE__));
+	debug (("..."));
 
 	iso_start = isodate_from_time_t (start);
 	if (!iso_start)
@@ -542,15 +556,17 @@ load_alarms (ClientAlarms *ca, time_t start, time_t end)
 		return;
 	}
 
-	str_query = g_strdup_printf ("(has-alarms-in-range? (make-time \"%s\") (make-time \"%s\"))",
-				     iso_start, iso_end);
+	str_query = g_strdup_printf (
+		"(has-alarms-in-range? (make-time \"%s\") "
+		"(make-time \"%s\"))", iso_start, iso_end);
 	g_free (iso_start);
 	g_free (iso_end);
 
 	/* create the live query */
 	if (ca->query) {
-		d(printf("%s:%d (load_alarms) - Disconnecting old queries \n",__FILE__, __LINE__));
-		g_signal_handlers_disconnect_matched (ca->query, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, ca);
+		debug (("Disconnecting old queries"));
+		g_signal_handlers_disconnect_matched (
+			ca->query, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, ca);
 		g_object_unref (ca->query);
 		ca->query = NULL;
 	}
@@ -559,14 +575,17 @@ load_alarms (ClientAlarms *ca, time_t start, time_t end)
 	if (!e_cal_get_query (ca->client, str_query, &ca->query, NULL)) {
 		g_warning (G_STRLOC ": Could not get query for client");
 	} else {
-		d(printf("%s:%d (load_alarms) - Setting Call backs \n",__FILE__, __LINE__));
+		debug (("Setting Call backs"));
 
-		g_signal_connect (G_OBJECT (ca->query), "objects_added",
-				  G_CALLBACK (query_objects_changed_cb), ca);
-		g_signal_connect (G_OBJECT (ca->query), "objects_modified",
-				  G_CALLBACK (query_objects_changed_cb), ca);
-		g_signal_connect (G_OBJECT (ca->query), "objects_removed",
-				  G_CALLBACK (query_objects_removed_cb), ca);
+		g_signal_connect (
+			ca->query, "objects_added",
+			G_CALLBACK (query_objects_changed_cb), ca);
+		g_signal_connect (
+			ca->query, "objects_modified",
+			G_CALLBACK (query_objects_changed_cb), ca);
+		g_signal_connect (
+			ca->query, "objects_removed",
+			G_CALLBACK (query_objects_removed_cb), ca);
 
 		e_cal_view_start (ca->query);
 	}
@@ -590,11 +609,12 @@ load_alarms_for_today (ClientAlarms *ca)
 	 * half-open; we do not want to display the "last" displayed alarm
 	 * twice, once when it occurs and once when the alarm daemon restarts.
 	 */
-	from = MAX (config_data_get_last_notification_time (ca->client) + 1, day_start);
+	from = config_data_get_last_notification_time (ca->client) + 1;
+	if (from <= 0)
+		from = MAX (from, day_start);
 
 	day_end = time_day_end_with_zone (now, zone);
-	d(printf("%s:%d (load_alarms_for_today) - From %s to %s\n",__FILE__, __LINE__,
-		 g_strdup (ctime (&from)), g_strdup (e_ctime (&day_end))));
+	debug (("From %s to %s", e_ctime (&from), e_ctime (&day_end)));
 	load_alarms (ca, from, day_end);
 }
 
@@ -606,7 +626,6 @@ cal_opened_cb (ECal *client, const GError *error, gpointer data)
 
 	ca = data;
 
-	d(printf("%s:%d (cal_opened_cb) - Opened Calendar %p (Status %d%s%s%s)\n",__FILE__, __LINE__, client, error ? error->code : 0, error ? " (" : "", error ? error->message : "", error ? ")" : ""));
 	if (error)
 		return;
 
@@ -625,7 +644,7 @@ remove_alarms (CompQueuedAlarms *cqa, gboolean free_object)
 {
 	GSList *l;
 
-	d(printf("%s:%d (remove_alarms) - Removing for %p\n",__FILE__, __LINE__, cqa));
+	debug (("Removing for %p", cqa));
 	for (l = cqa->queued_alarms; l;) {
 		QueuedAlarm *qa;
 
@@ -649,7 +668,7 @@ remove_comp (ClientAlarms *ca, ECalComponentId *id)
 {
 	CompQueuedAlarms *cqa;
 
-	d(printf("%s:%d (remove_comp) - Removing uid %s\n",__FILE__, __LINE__, id->uid));
+	debug (("Removing uid %s", id->uid));
 
 	if (id->rid && !(*(id->rid))) {
 		g_free (id->rid);
@@ -665,7 +684,7 @@ remove_comp (ClientAlarms *ca, ECalComponentId *id)
 	 */
 	g_return_if_fail (cqa->queued_alarms != NULL);
 
-	d(printf("%s:%d (remove_comp) - Removing CQA %p\n",__FILE__, __LINE__, cqa));
+	debug (("Removing CQA %p", cqa));
 	remove_alarms (cqa, TRUE);
 }
 
@@ -730,7 +749,7 @@ query_objects_changed_async (struct _query_msg *msg)
 
 	day_end = time_day_end_with_zone (time (NULL), zone);
 
-	d(printf("%s:%d (query_objects_changed_async) - Querying for object between %s to %s\n",__FILE__, __LINE__, e_ctime(&from), e_ctime(&day_end)));
+	debug (("Querying for object between %s to %s", e_ctime (&from), e_ctime (&day_end)));
 
 	for (l = objects; l != NULL; l = l->next) {
 		ECalComponentId *id;
@@ -743,7 +762,7 @@ query_objects_changed_async (struct _query_msg *msg)
 		found = e_cal_get_alarms_for_object (ca->client, id, from, day_end, &alarms);
 
 		if (!found) {
-			d(printf("%s:%d (query_objects_changed_async) - No Alarm found for client %p\n",__FILE__, __LINE__, ca->client));
+			debug (("No Alarm found for client %p", ca->client));
 			tray_list_remove_cqa (lookup_comp_queued_alarms (ca, id));
 			remove_comp (ca, id);
 			g_hash_table_remove (ca->uid_alarms_hash, id);
@@ -755,15 +774,16 @@ query_objects_changed_async (struct _query_msg *msg)
 
 		cqa = lookup_comp_queued_alarms (ca, id);
 		if (!cqa) {
-			d(printf("%s:%d (query_objects_changed_async) - No currently queued alarms for %s\n",__FILE__, __LINE__, id->uid));
+			debug (("No currently queued alarms for %s", id->uid));
 			add_component_alarms (ca, alarms);
 			g_object_unref (comp);
 			comp = NULL;
 			continue;
 		}
 
-		d(printf("%s:%d (query_objects_changed_async) - Alarm Already Exist for %s\n",__FILE__, __LINE__, id->uid));
-		/* if the alarms or the alarms list is empty remove it after updating the cqa structure */
+		debug (("Alarm Already Exist for %s", id->uid));
+		/* If the alarms or the alarms list is empty,
+		 * remove it after updating the cqa structure. */
 		if (alarms == NULL || alarms->alarms == NULL) {
 
 			/* update the cqa and its queued alarms for changes in summary and alarm_uid  */
@@ -794,7 +814,7 @@ query_objects_changed_async (struct _query_msg *msg)
 
 			alarm_id = alarm_add (instance->trigger, alarm_trigger_cb, cqa, NULL);
 			if (!alarm_id) {
-				d(printf("%s:%d (query_objects_changed_async) -Unable to schedule trigger for %s \n",__FILE__, __LINE__, e_ctime(&(instance->trigger))));
+				debug (("Unable to schedule trigger for %s", e_ctime (&(instance->trigger))));
 				continue;
 			}
 
@@ -804,7 +824,7 @@ query_objects_changed_async (struct _query_msg *msg)
 			qa->snooze = FALSE;
 			qa->orig_trigger = instance->trigger;
 			cqa->queued_alarms = g_slist_prepend (cqa->queued_alarms, qa);
-			d(printf("%s:%d (query_objects_changed_async) - Adding %p to queue \n",__FILE__, __LINE__, qa));
+			debug (("Adding %p to queue", qa));
 		}
 
 		cqa->queued_alarms = g_slist_reverse (cqa->queued_alarms);
@@ -842,7 +862,7 @@ query_objects_removed_async (struct _query_msg *msg)
 	ca = msg->data;
 	objects = msg->objects;
 
-	d(printf("%s:%d (query_objects_removed_async) - Removing %d objects\n",__FILE__, __LINE__, g_list_length(objects)));
+	debug (("Removing %d objects", g_list_length (objects)));
 
 	for (l = objects; l != NULL; l = l->next) {
 		/* If the alarm is already triggered remove it. */
@@ -892,14 +912,14 @@ create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, gint snooze_mins)
 
 	new_id = alarm_add (t, alarm_trigger_cb, cqa, NULL);
 	if (!new_id) {
-		d(printf("%s:%d (create_snooze) -Unable to schedule trigger for %s \n",__FILE__, __LINE__, e_ctime(&t)));
+		debug (("Unable to schedule trigger for %s", e_ctime (&t)));
 		return;
 	}
 
 	orig_qa->instance->trigger = t;
 	orig_qa->alarm_id = new_id;
 	orig_qa->snooze = TRUE;
-	d(printf("%s:%d (create_snooze) - Adding a alarm at %s\n",__FILE__, __LINE__, e_ctime(&t)));
+	debug (("Adding a alarm at %s", e_ctime (&t)));
 }
 
 /* Launches a component editor for a component */
@@ -1010,7 +1030,7 @@ on_dialog_objs_removed_async (struct _query_msg *msg)
 	TrayIconData *tray_data;
 	GList *objects;
 
-	d(printf("%s:%d (on_dialog_objs_removed_async)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	tray_data = msg->data;
 	objects = msg->objects;
@@ -1059,7 +1079,7 @@ tray_list_remove_cqa_async (struct _tray_cqa_msg *msg)
 	CompQueuedAlarms *cqa = msg->cqa;
 	GList *list = tray_icons_list;
 
-	d(printf("%s:%d (tray_list_remove_cqa_async) - Removing CQA %p from tray list\n",__FILE__, __LINE__, cqa));
+	debug (("Removing CQA %p from tray list", cqa));
 
 	while (list) {
 		TrayIconData *tray_data = list->data;
@@ -1068,17 +1088,18 @@ tray_list_remove_cqa_async (struct _tray_cqa_msg *msg)
 
 		list = list->next;
 		if (tray_data->cqa == cqa) {
-			d(printf("%s:%d (tray_list_remove_cqa_async) - Found.\n", __FILE__, __LINE__));
+			debug (("Found"));
 			tray_icons_list = g_list_delete_link (tray_icons_list, tmp);
 			if (alarm_notifications_dialog) {
-				model = gtk_tree_view_get_model (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
+				model = gtk_tree_view_get_model (
+					GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
 				gtk_list_store_remove (GTK_LIST_STORE (model), &(tray_data->iter));
 			}
 			free_tray_icon_data (tray_data);
 		}
 	}
 
-	d(printf("%s:%d (tray_list_remove_cqa_async) - %d alarms left.\n", __FILE__, __LINE__, g_list_length (tray_icons_list)));
+	debug (("%d alarms left", g_list_length (tray_icons_list)));
 
 	if (alarm_notifications_dialog) {
 		if (!g_list_length (tray_icons_list)) {
@@ -1087,11 +1108,14 @@ tray_list_remove_cqa_async (struct _tray_cqa_msg *msg)
 			alarm_notifications_dialog = NULL;
 		} else {
 			GtkTreeIter iter;
-			GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
+			GtkTreeModel *model;
 			GtkTreeSelection *sel;
 
+			model = gtk_tree_view_get_model (
+				GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
 			gtk_tree_model_get_iter_first (model, &iter);
-			sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
+			sel = gtk_tree_view_get_selection (
+				GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
 			gtk_tree_selection_select_iter (sel, &iter);
 		}
 	}
@@ -1117,7 +1141,7 @@ tray_list_remove_async (Message *msg)
 {
 	GList *list = tray_icons_list;
 
-	d(printf("%s:%d (tray_list_remove_async) - Removing %d alarms\n",__FILE__, __LINE__, g_list_length(list)));
+	debug (("Removing %d alarms", g_list_length (list)));
 	while (list != NULL) {
 
 		TrayIconData *tray_data = list->data;
@@ -1129,7 +1153,9 @@ tray_list_remove_async (Message *msg)
 			tray_icons_list = g_list_remove_link (tray_icons_list, list);
 			status = remove_queued_alarm (tray_data->cqa, tray_data->alarm_id, FALSE, TRUE);
 			if (status) {
-				g_hash_table_remove (tray_data->cqa->parent_client->uid_alarms_hash, tray_data->cqa->id);
+				g_hash_table_remove (
+					tray_data->cqa->parent_client->uid_alarms_hash,
+					tray_data->cqa->id);
 				e_cal_component_free_id (tray_data->cqa->id);
 				g_free (tray_data->cqa);
 			}
@@ -1168,7 +1194,7 @@ tray_list_remove_data_async (struct _tray_msg *msg)
 {
 	TrayIconData *tray_data = msg->data;
 
-	d(printf("%s:%d (tray_list_remove_data_async) - Removing %p from tray list\n",__FILE__, __LINE__, tray_data));
+	debug (("Removing %p from tray list", tray_data));
 
 	tray_icons_list = g_list_remove_all (tray_icons_list, tray_data);
 	free_tray_icon_data (tray_data);
@@ -1194,14 +1220,14 @@ notify_dialog_cb (AlarmNotifyResult result, gint snooze_mins, gpointer data)
 {
 	TrayIconData *tray_data = data;
 
-	d(printf("%s:%d (notify_dialog_cb) - Received from dialog\n",__FILE__, __LINE__));
+	debug (("Received from dialog"));
 
 	g_signal_handlers_disconnect_matched (tray_data->query, G_SIGNAL_MATCH_FUNC,
 					      0, 0, NULL, on_dialog_objs_removed_cb, NULL);
 
 	switch (result) {
 	case ALARM_NOTIFY_SNOOZE:
-		d(printf("%s:%d (notify_dialog_cb) - Creating a snooze\n",__FILE__, __LINE__));
+		debug (("Creating a snooze"));
 		create_snooze (tray_data->cqa, tray_data->alarm_id, snooze_mins);
 		tray_data->snooze_set = TRUE;
 		tray_list_remove_data (tray_data);
@@ -1237,13 +1263,16 @@ notify_dialog_cb (AlarmNotifyResult result, gint snooze_mins, gpointer data)
 
 	case ALARM_NOTIFY_DISMISS:
 		if (alarm_notifications_dialog) {
-			GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
+			GtkTreeModel *model;
+
+			model = gtk_tree_view_get_model (
+				GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
 			gtk_list_store_remove (GTK_LIST_STORE (model), &tray_data->iter);
 		}
 		break;
 
 	case ALARM_NOTIFY_CLOSE:
-		d(printf("%s:%d (notify_dialog_cb) - Dialog close\n",__FILE__, __LINE__));
+		debug (("Dialog close"));
 		if (alarm_notifications_dialog) {
 			GtkTreeIter iter;
 			GtkTreeModel *model =
@@ -1293,7 +1322,7 @@ open_alarm_dialog (TrayIconData *tray_data)
 {
 	QueuedAlarm *qa;
 
-	d(printf("%s:%d (open_alarm_dialog) \n",__FILE__, __LINE__));
+	debug (("..."));
 	qa = lookup_queued_alarm (tray_data->cqa, tray_data->alarm_id);
 	if (qa) {
 		remove_tray_icon ();
@@ -1334,7 +1363,7 @@ static gint
 tray_icon_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 	if (event->type == GDK_BUTTON_PRESS) {
-			d(printf("%s:%d (tray_icon_clicked_cb) - left click and %d alarms\n",__FILE__, __LINE__, g_list_length (tray_icons_list)));
+		debug (("left click and %d alarms", g_list_length (tray_icons_list)));
 		if (event->button == 1 && g_list_length (tray_icons_list) > 0) {
 			GList *tmp;
 			for (tmp = tray_icons_list; tmp; tmp = tmp->next) {
@@ -1343,7 +1372,7 @@ tray_icon_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_da
 
 			return TRUE;
 		} else if (event->button == 3) {
-			d(printf("%s:%d (tray_icon_clicked_cb) - right click\n",__FILE__, __LINE__));
+			debug (("right click"));
 
 			remove_tray_icon ();
 			return TRUE;
@@ -1390,9 +1419,9 @@ tray_icon_blink_cb (gpointer data)
 	tray_blink_state = !tray_blink_state;
 
 	if (tray_blink_state || tray_blink_countdown <= 0)
-		icon_name = "stock_appointment-reminder-excl";
+		icon_name = "appointment-missed";
 	else
-		icon_name = "stock_appointment-reminder";
+		icon_name = "appointment-soon";
 
 	if (tray_icon)
 		gtk_status_icon_set_from_icon_name (tray_icon, icon_name);
@@ -1440,7 +1469,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	icaltimezone *current_zone;
 	ECalComponentOrganizer organiser;
 
-	d(printf("%s:%d (display_notification)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	comp = cqa->alarms->comp;
 	qa = lookup_queued_alarm (cqa, alarm_id);
@@ -1479,7 +1508,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (tray_icon == NULL) {
 		tray_icon = gtk_status_icon_new ();
 		gtk_status_icon_set_from_icon_name (
-			tray_icon, "stock_appointment-reminder");
+			tray_icon, "appointment-soon");
 		g_signal_connect (G_OBJECT (tray_icon), "activate",
 				  G_CALLBACK (icon_activated), NULL);
 		g_signal_connect (G_OBJECT (tray_icon), "popup-menu",
@@ -1516,7 +1545,10 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (g_list_length (tray_icons_list) > 1) {
 		gchar *tip;
 
-		tip =  g_strdup_printf (ngettext ("You have %d alarm", "You have %d alarms", g_list_length (tray_icons_list)), g_list_length (tray_icons_list));
+		tip =  g_strdup_printf (ngettext (
+			"You have %d alarm", "You have %d alarms",
+			g_list_length (tray_icons_list)),
+			g_list_length (tray_icons_list));
 		gtk_status_icon_set_tooltip_text (tray_icon, tip);
 	}
 	else {
@@ -1562,7 +1594,7 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 	NotifyNotification *n;
 	gchar *body;
 
-	d(printf("%s:%d (popup_notification)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	comp = cqa->alarms->comp;
 	qa = lookup_queued_alarm (cqa, alarm_id);
@@ -1595,18 +1627,30 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 
 	if (organiser.cn) {
 		if (location)
-			body = g_strdup_printf ("<b>%s</b>\n%s %s\n%s %s", organiser.cn, _("Location:"), location, start_str, time_str);
+			body = g_strdup_printf (
+				"<b>%s</b>\n%s %s\n%s %s",
+				organiser.cn, _("Location:"),
+				location, start_str, time_str);
 		else
-			body = g_strdup_printf ("<b>%s</b>\n%s %s", organiser.cn, start_str, time_str);
+			body = g_strdup_printf (
+				"<b>%s</b>\n%s %s",
+				organiser.cn, start_str, time_str);
 	}
 	else {
 		if (location)
-			body = g_strdup_printf ("%s %s\n%s %s", _("Location:"), location, start_str, time_str);
+			body = g_strdup_printf (
+				"%s %s\n%s %s", _("Location:"),
+				location, start_str, time_str);
 		else
-			body = g_strdup_printf ("%s %s", start_str, time_str);
+			body = g_strdup_printf (
+				"%s %s", start_str, time_str);
 	}
 
-	n = notify_notification_new (summary, body, "stock_appointment-reminder", NULL);
+#ifdef HAVE_LIBNOTIFY_07
+	n = notify_notification_new (summary, body, "appointment-soon");
+#else
+	n = notify_notification_new (summary, body, "appointment-soon", NULL);
+#endif /* HAVE_LIBNOTIFY_07 */
 	if (!notify_notification_show (n, NULL))
 	    g_warning ("Could not send notification to daemon\n");
 
@@ -1631,7 +1675,7 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 	icalattach *attach;
 	gint	flag = 0;
 
-	d(printf("%s:%d (audio_notification)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	comp = cqa->alarms->comp;
 	qa = lookup_queued_alarm (cqa, alarm_id);
@@ -1685,7 +1729,7 @@ mail_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id)
 
 	/* FIXME */
 
-	d(printf("%s:%d (mail_notification)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	if (!e_cal_get_static_capability (cqa->parent_client->client,
 						CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS))
@@ -1719,7 +1763,7 @@ procedure_notification_dialog (const gchar *cmd, const gchar *url)
 	gchar *str;
 	gint btn;
 
-	d(printf("%s:%d (procedure_notification_dialog)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	if (config_data_is_blessed_program (url))
 		return TRUE;
@@ -1751,7 +1795,8 @@ procedure_notification_dialog (const gchar *cmd, const gchar *url)
 
 	/* Run the dialog */
 	btn = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (btn == GTK_RESPONSE_OK && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)))
+	if (btn == GTK_RESPONSE_OK &&
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)))
 		config_data_save_blessed_program (url);
 	gtk_widget_destroy (dialog);
 
@@ -1770,7 +1815,7 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	gchar *cmd;
 	gboolean result = TRUE;
 
-	d(printf("%s:%d (procedure_notification)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	comp = cqa->alarms->comp;
 	qa = lookup_queued_alarm (cqa, alarm_id);
@@ -1827,7 +1872,7 @@ check_midnight_refresh (gpointer user_data)
 	time_t new_midnight;
 	icaltimezone *zone;
 
-	d(printf("%s:%d (check_midnight_refresh)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	zone = config_data_get_timezone ();
 	new_midnight = time_day_end_with_zone (time (NULL), zone);
@@ -1857,14 +1902,14 @@ alarm_queue_init (gpointer data)
 	an = data;
 	g_return_if_fail (alarm_queue_inited == FALSE);
 
-	d(printf("%s:%d (alarm_queue_init)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 	client_alarms_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 	queue_midnight_refresh ();
 
 	if (config_data_get_last_notification_time (NULL) == -1) {
-		time_t tmval = time (NULL);
-		d(printf("%s:%d (alarm_queue_init) - Setting last notification time to %s\n",__FILE__, __LINE__, e_ctime(&tmval)));
+		time_t tmval = time_day_begin (time (NULL));
+		debug (("Setting last notification time to %s", e_ctime (&tmval)));
 		config_data_set_last_notification_time (NULL, tmval);
 	}
 
@@ -1883,12 +1928,12 @@ free_client_alarms_cb (gpointer key, gpointer value, gpointer user_data)
 {
 	ClientAlarms *ca = value;
 
-	d(printf("%s:%d (free_client_alarms_cb) - %p\n",__FILE__, __LINE__, ca));
+	debug (("ca=%p", ca));
 
 	if (ca) {
 		remove_client_alarms (ca);
 		if (ca->client) {
-			d(printf("%s:%d (free_client_alarms_cb) - Disconnecting Client \n",__FILE__, __LINE__));
+			debug (("Disconnecting Client"));
 
 			g_signal_handlers_disconnect_matched (ca->client, G_SIGNAL_MATCH_DATA,
 							      0, 0, NULL, NULL, ca);
@@ -1896,7 +1941,7 @@ free_client_alarms_cb (gpointer key, gpointer value, gpointer user_data)
 		}
 
 		if (ca->query) {
-			d(printf("%s:%d (free_client_alarms_cb) - Disconnecting Query \n",__FILE__, __LINE__));
+			debug (("Disconnecting Query"));
 
 			g_signal_handlers_disconnect_matched (ca->query, G_SIGNAL_MATCH_DATA,
 							      0, 0, NULL, NULL, ca);
@@ -1927,9 +1972,10 @@ alarm_queue_done (void)
 	/* All clients must be unregistered by now */
 	g_return_if_fail (g_hash_table_size (client_alarms_hash) == 0);
 
-	d(printf("%s:%d (alarm_queue_done)\n",__FILE__, __LINE__));
+	debug (("..."));
 
-	g_hash_table_foreach_remove (client_alarms_hash, (GHRFunc) free_client_alarms_cb, NULL);
+	g_hash_table_foreach_remove (
+		client_alarms_hash, (GHRFunc) free_client_alarms_cb, NULL);
 	g_hash_table_destroy (client_alarms_hash);
 	client_alarms_hash = NULL;
 
@@ -1990,7 +2036,7 @@ alarm_queue_add_async (struct _alarm_client_msg *msg)
 		return;
 	}
 
-	d(printf("%s:%d (alarm_queue_add_async) - %p\n",__FILE__, __LINE__, client));
+	debug (("client=%p", client));
 
 	ca = g_new (ClientAlarms, 1);
 
@@ -1999,7 +2045,8 @@ alarm_queue_add_async (struct _alarm_client_msg *msg)
 
 	g_hash_table_insert (client_alarms_hash, client, ca);
 
-	ca->uid_alarms_hash = g_hash_table_new ((GHashFunc) hash_ids, (GEqualFunc) compare_ids);
+	ca->uid_alarms_hash = g_hash_table_new (
+		(GHashFunc) hash_ids, (GEqualFunc) compare_ids);
 
 	if (e_cal_get_load_state (client) == E_CAL_LOAD_LOADED) {
 		load_alarms_for_today (ca);
@@ -2048,7 +2095,7 @@ remove_cqa (ClientAlarms *ca, ECalComponentId *id, CompQueuedAlarms *cqa)
 	 */
 	g_return_if_fail (cqa->queued_alarms != NULL);
 
-	d(printf("%s:%d (remove_cqa) - removing %d alarms\n",__FILE__, __LINE__, g_slist_length(cqa->queued_alarms)));
+	debug (("removing %d alarms", g_slist_length (cqa->queued_alarms)));
 	remove_alarms (cqa, TRUE);
 }
 
@@ -2057,7 +2104,7 @@ remove_comp_by_id (gpointer key, gpointer value, gpointer userdata) {
 
 	ClientAlarms *ca = (ClientAlarms *)userdata;
 
-	d(printf("%s:%d (remove_comp_by_id)\n",__FILE__, __LINE__));
+	debug (("..."));
 
 /*	if (!g_hash_table_size (ca->uid_alarms_hash)) */
 /*		return; */
@@ -2071,7 +2118,7 @@ remove_comp_by_id (gpointer key, gpointer value, gpointer userdata) {
 static void
 remove_client_alarms (ClientAlarms *ca)
 {
-	d(printf("%s:%d (remove_client_alarms) - size %d \n",__FILE__, __LINE__, g_hash_table_size (ca->uid_alarms_hash)));
+	debug (("size %d", g_hash_table_size (ca->uid_alarms_hash)));
 
 	g_hash_table_foreach_remove  (ca->uid_alarms_hash, (GHRFunc)remove_comp_by_id, ca);
 
@@ -2098,12 +2145,12 @@ alarm_queue_remove_async (struct _alarm_client_msg *msg)
 	ca = lookup_client (client);
 	g_return_if_fail (ca != NULL);
 
-	d(printf("%s:%d (alarm_queue_remove_async) \n",__FILE__, __LINE__));
+	debug (("..."));
 	remove_client_alarms (ca);
 
 	/* Clean up */
 	if (ca->client) {
-		d(printf("%s:%d (alarm_queue_remove_async) - Disconnecting Client \n",__FILE__, __LINE__));
+		debug (("Disconnecting Client"));
 
 		g_signal_handlers_disconnect_matched (ca->client, G_SIGNAL_MATCH_DATA,
 						      0, 0, NULL, NULL, ca);
@@ -2112,7 +2159,7 @@ alarm_queue_remove_async (struct _alarm_client_msg *msg)
 	}
 
 	if (ca->query) {
-		d(printf("%s:%d (alarm_queue_remove_async) - Disconnecting Query \n",__FILE__, __LINE__));
+		debug (("Disconnecting Query"));
 
 		g_signal_handlers_disconnect_matched (ca->query, G_SIGNAL_MATCH_DATA,
 						      0, 0, NULL, NULL, ca);
@@ -2133,8 +2180,8 @@ alarm_queue_remove_async (struct _alarm_client_msg *msg)
 /** alarm_queue_remove_client
  *
  * asynchronously remove client from alarm queue.
- * @param client Client to remove.
- * @param immediately Indicates whether use thread or do it right now.
+ * @client: Client to remove.
+ * @immediately: Indicates whether use thread or do it right now.
  */
 
 void
@@ -2152,8 +2199,8 @@ alarm_queue_remove_client (ECal *client, gboolean immediately)
 		message_push ((Message *) msg);
 }
 
-/* Update non-time related variables for various structures on modification of an existing component
-   to be called only from query_objects_changed_cb */
+/* Update non-time related variables for various structures on modification
+ * of an existing component to be called only from query_objects_changed_cb */
 static void
 update_cqa (CompQueuedAlarms *cqa, ECalComponent *newcomp)
 {
@@ -2170,7 +2217,7 @@ update_cqa (CompQueuedAlarms *cqa, ECalComponent *newcomp)
 	from = time_day_begin_with_zone (time (NULL), zone);
 	to = time_day_end_with_zone (time (NULL), zone);
 
-	d(printf("%s:%d (update_cqa) - Generating alarms between %s and %s\n",__FILE__, __LINE__, e_ctime(&from), e_ctime(&to)));
+	debug (("Generating alarms between %s and %s", e_ctime (&from), e_ctime (&to)));
 	alarms = e_cal_util_generate_alarms_for_comp (newcomp, from, to, omit,
 					e_cal_resolve_tzid_cb, cqa->parent_client->client, zone);
 
@@ -2189,7 +2236,7 @@ update_cqa (CompQueuedAlarms *cqa, ECalComponent *newcomp)
 			if (alarm) { /* Need to update QueuedAlarms */
 				e_cal_component_alarm_free (alarm);
 				if (alarms == NULL) {
-					d(printf("%s:%d (update_cqa) - No alarms found in the modified component\n",__FILE__, __LINE__));
+					debug (("No alarms found in the modified component"));
 					break;
 				}
 				update_qa (alarms, qa);
@@ -2212,10 +2259,14 @@ update_qa (ECalComponentAlarms *alarms, QueuedAlarm *qa)
 	ECalComponentAlarmInstance *al_inst;
 	GSList *instance_list;
 
-	d(printf("%s:%d (update_qa)\n",__FILE__, __LINE__));
-	for (instance_list = alarms->alarms; instance_list; instance_list = instance_list->next) {
+	debug (("..."));
+	for (instance_list = alarms->alarms;
+	     instance_list;
+	     instance_list = instance_list->next) {
 		al_inst = instance_list->data;
-		if (al_inst->trigger == qa->orig_trigger) {  /* FIXME if two or more alarm instances (audio, note)									  for same component have same trigger */
+		/* FIXME If two or more alarm instances (audio, note)
+		 *       for same component have same trigger... */
+		if (al_inst->trigger == qa->orig_trigger) {
 			g_free ((gchar *) qa->instance->auid);
 			qa->instance->auid = g_strdup (al_inst->auid);
 			break;
