@@ -106,8 +106,8 @@ calendar_view_finalize (GObject *object)
 	g_free (priv);
 	cal_view->priv = NULL;
 
-	if (G_OBJECT_CLASS (calendar_view_parent_class)->finalize)
-		(* G_OBJECT_CLASS (calendar_view_parent_class)->finalize) (object);
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (calendar_view_parent_class)->finalize (object);
 }
 
 
