@@ -33,10 +33,6 @@
 #include <glib/gi18n.h>
 #include "e-timezone-entry.h"
 
-#define E_TIMEZONE_ENTRY_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_TIMEZONE_ENTRY, ETimezoneEntryPrivate))
-
 struct _ETimezoneEntryPrivate {
 	/* The current timezone, set in e_timezone_entry_set_timezone()
 	   or from the timezone dialog. Note that we don't copy it or
@@ -217,7 +213,7 @@ timezone_entry_mnemonic_activate (GtkWidget *widget,
 {
 	ETimezoneEntryPrivate *priv;
 
-	priv = E_TIMEZONE_ENTRY_GET_PRIVATE (widget);
+	priv = E_TIMEZONE_ENTRY (widget)->priv;
 
 	if (gtk_widget_get_can_focus (widget)) {
 		if (priv->button != NULL)
@@ -233,47 +229,23 @@ timezone_entry_focus (GtkWidget *widget,
 {
 	ETimezoneEntryPrivate *priv;
 
-	priv = E_TIMEZONE_ENTRY_GET_PRIVATE (widget);
+	priv = E_TIMEZONE_ENTRY (widget)->priv;
 
 	if (direction == GTK_DIR_TAB_FORWARD) {
-#if GTK_CHECK_VERSION(2,19,7)
 		if (gtk_widget_has_focus (priv->entry))
-#else
-		if (GTK_WIDGET_HAS_FOCUS (priv->entry))
-#endif
 			gtk_widget_grab_focus (priv->button);
-#if GTK_CHECK_VERSION(2,19,7)
 		else if (gtk_widget_has_focus (priv->button))
-#else
-		else if (GTK_WIDGET_HAS_FOCUS (priv->button))
-#endif
 			return FALSE;
-#if GTK_CHECK_VERSION(2,19,7)
 		else if (gtk_widget_get_visible (priv->entry))
-#else
-		else if (GTK_WIDGET_VISIBLE (priv->entry))
-#endif
 			gtk_widget_grab_focus (priv->entry);
 		else
 			gtk_widget_grab_focus (priv->button);
 
 	} else if (direction == GTK_DIR_TAB_BACKWARD) {
-#if GTK_CHECK_VERSION(2,19,7)
 		if (gtk_widget_has_focus (priv->entry))
-#else
-		if (GTK_WIDGET_HAS_FOCUS (priv->entry))
-#endif
 			return FALSE;
-#if GTK_CHECK_VERSION(2,19,7)
 		else if (gtk_widget_has_focus (priv->button)) {
-#else
-		else if (GTK_WIDGET_HAS_FOCUS (priv->button)) {
-#endif
-#if GTK_CHECK_VERSION(2,19,7)
 			if (gtk_widget_get_visible (priv->entry))
-#else
-			if (GTK_WIDGET_VISIBLE (priv->entry))
-#endif
 				gtk_widget_grab_focus (priv->entry);
 			else
 				return FALSE;
@@ -326,9 +298,10 @@ e_timezone_entry_init (ETimezoneEntry *timezone_entry)
 	AtkObject *a11y;
 	GtkWidget *widget;
 
-	timezone_entry->priv = E_TIMEZONE_ENTRY_GET_PRIVATE (timezone_entry);
+	timezone_entry->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		timezone_entry, E_TYPE_TIMEZONE_ENTRY, ETimezoneEntryPrivate);
 
-	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (timezone_entry), GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (GTK_WIDGET (timezone_entry), TRUE);
 
 	widget  = gtk_entry_new ();
 	gtk_editable_set_editable (GTK_EDITABLE (widget), FALSE);
