@@ -30,14 +30,10 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
-#include <libgnomecanvas/gnome-canvas-text.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 #include <e-util/e-util.h>
 #include "weekday-picker.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define PADDING 2
 
 /* Private part of the WeekdayPicker structure */
@@ -174,7 +170,7 @@ configure_items (WeekdayPicker *wp)
 				       "y1", (double) 0,
 				       "x2", (double) ((i + 1) * box_width),
 				       "y2", (double) (height - 1),
-				       "width_pixels", 0,
+				       "line_width", 0.0,
 				       NULL);
 
 		c = get_day_text (day);
@@ -182,7 +178,6 @@ configure_items (WeekdayPicker *wp)
 				       "text", c,
 				       "x", (double) (i * box_width) + box_width / 2.0,
 				       "y", (double) (1 + PADDING),
-				       "anchor", GTK_ANCHOR_N,
 				       NULL);
 		g_free (c);
 	}
@@ -206,8 +201,7 @@ weekday_picker_dispose (GObject *object)
 	wp->priv = NULL;
 
 	/* Chain up to parent's dispose() method. */
-	if (G_OBJECT_CLASS (weekday_picker_parent_class)->dispose)
-		G_OBJECT_CLASS (weekday_picker_parent_class)->dispose (object);
+	G_OBJECT_CLASS (weekday_picker_parent_class)->dispose (object);
 }
 
 static void
@@ -224,8 +218,9 @@ weekday_picker_realize (GtkWidget *widget)
 }
 
 static void
-weekday_picker_size_request (GtkWidget *widget,
-                             GtkRequisition *requisition)
+weekday_picker_get_preferred_width (GtkWidget *widget,
+                                    gint *minimum_width,
+                                    gint *natural_width)
 {
 	WeekdayPicker *wp;
 	WeekdayPickerPrivate *priv;
@@ -233,8 +228,22 @@ weekday_picker_size_request (GtkWidget *widget,
 	wp = WEEKDAY_PICKER (widget);
 	priv = wp->priv;
 
-	requisition->width = (priv->max_letter_width + 2 * PADDING + 1) * 7 + 1;
-	requisition->height = (priv->font_ascent + priv->font_descent + 2 * PADDING + 2);
+	*minimum_width = *natural_width = (priv->max_letter_width + 2 * PADDING + 1) * 7 + 1;
+}
+
+static void
+weekday_picker_get_preferred_height (GtkWidget *widget,
+                                     gint *minimum_height,
+                                     gint *natural_height)
+{
+	WeekdayPicker *wp;
+	WeekdayPickerPrivate *priv;
+
+	wp = WEEKDAY_PICKER (widget);
+	priv = wp->priv;
+
+	*minimum_height = *natural_height =
+		(priv->font_ascent + priv->font_descent + 2 * PADDING + 2);
 }
 
 static void
@@ -351,7 +360,8 @@ weekday_picker_class_init (WeekdayPickerClass *class)
 
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->realize = weekday_picker_realize;
-	widget_class->size_request = weekday_picker_size_request;
+	widget_class->get_preferred_width = weekday_picker_get_preferred_width;
+	widget_class->get_preferred_height = weekday_picker_get_preferred_height;
 	widget_class->size_allocate = weekday_picker_size_allocate;
 	widget_class->style_set = weekday_picker_style_set;
 	widget_class->focus = weekday_picker_focus;
