@@ -24,6 +24,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <locale.h>
 #include <unistd.h>
 #include <string.h>
 #include <stdio.h>
@@ -76,9 +77,7 @@ mail_message_received_cb (UniqueApp         *app G_GNUC_UNUSED,
                          guint              time_ G_GNUC_UNUSED,
                          gpointer           user_data)
 {
-	 gchar *url;
 	 GtkWindow *window = (GtkWindow *) user_data;
-	 gchar *args[2];
 
 	 switch (command) {
 	 case UNIQUE_ACTIVATE :
@@ -90,12 +89,6 @@ mail_message_received_cb (UniqueApp         *app G_GNUC_UNUSED,
 		  return UNIQUE_RESPONSE_OK;
 
 	 case UNIQUE_OPEN :
-		  url = unique_message_data_get_text (message_data);
-		  args[0] = url;
-		  args[1] = NULL;
-		  //mail_shell_set_cmdline_args ((MailShell *)window, args);
-		  //mail_shell_handle_cmdline ((MailShell *)window);
-		  g_free (url);
 		  gdk_window_raise (gtk_widget_get_window (GTK_WIDGET (window)));
 		  gtk_window_deiconify (window);
 		  gtk_window_present (window);
@@ -142,14 +135,14 @@ check_and_set_default_mail (void)
 	GConfClient *client = gconf_client_get_default ();
 	gchar *mailer;
 
-	mailer  = gconf_client_get_string(client, GCONF_KEY_MAILTO_COMMAND, NULL);
+	mailer  = gconf_client_get_string (client, GCONF_KEY_MAILTO_COMMAND, NULL);
 	if (mailer && *mailer && (strcmp (mailer, ANJAL_MAILTO_COMMAND) == 0)) {
 		g_object_unref (client);
 		return; /* Anjal is the default mailer */
 	}
 
-	gconf_client_set_bool(client, GCONF_KEY_MAILTO_ENABLED, TRUE, NULL);
-	gconf_client_set_string(client, GCONF_KEY_MAILTO_COMMAND, ANJAL_MAILTO_COMMAND, NULL);
+	gconf_client_set_bool (client, GCONF_KEY_MAILTO_ENABLED, TRUE, NULL);
+	gconf_client_set_string (client, GCONF_KEY_MAILTO_COMMAND, ANJAL_MAILTO_COMMAND, NULL);
 	g_object_unref (client);
 }
 
@@ -167,7 +160,7 @@ idle_cb (MailCappletShell *mshell G_GNUC_UNUSED)
 static void
 create_default_shell (void)
 {
-	main_window = mail_capplet_shell_new(socket_id, FALSE, TRUE);
+	main_window = mail_capplet_shell_new (socket_id, FALSE, TRUE);
 	if (!socket_id)
 		gtk_widget_show (main_window);
 	g_idle_add ((GSourceFunc) idle_cb, remaining_args);
@@ -240,19 +233,19 @@ main (gint argc, gchar *argv[])
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-	gtk_set_locale ();
+	setlocale (LC_ALL, NULL);
 
 	if (!gtk_init_with_args (&argc, &argv, _("Anjal email client"), entries, NULL, &error)) {
 		g_error ("Unable to start Anjal: %s\n", error->message);
-		g_error_free(error);
+		g_error_free (error);
 	}
 
 	if (!g_thread_get_initialized ())
 		g_thread_init (NULL);
 
-	client = gconf_client_get_default();
+	client = gconf_client_get_default ();
 
-	e_passwords_init();
+	e_passwords_init ();
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default(), PACKAGE_DATA_DIR G_DIR_SEPARATOR_S "anjal" G_DIR_SEPARATOR_S "icons");
 	categories_icon_theme_hack ();
 
