@@ -36,10 +36,6 @@
 #include "shell/e-shell.h"
 #include "shell/e-shell-settings.h"
 
-#define EM_FORMAT_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), EM_TYPE_FORMAT, EMFormatPrivate))
-
 #define d(x)
 
 typedef struct _EMFormatCache EMFormatCache;
@@ -154,6 +150,7 @@ emf_finalize (GObject *object)
 	g_free (emf->charset);
 	g_free (emf->default_charset);
 	g_string_free (emf->part_id, TRUE);
+	g_free (emf->current_message_part_id);
 	g_free (emf->uid);
 
 	if (emf->pending_uri_table != NULL)
@@ -244,6 +241,7 @@ emf_format_clone (EMFormat *emf,
 		emf->message = msg;
 	}
 
+	emf->current_message_part_id = g_strdup ("root-message");
 	g_string_truncate (emf->part_id, 0);
 	if (folder != NULL)
 		/* TODO build some string based on the folder name/location? */
@@ -358,7 +356,8 @@ emf_init (EMFormat *emf)
 	EShell *shell;
 	EShellSettings *shell_settings;
 
-	emf->priv = EM_FORMAT_GET_PRIVATE (emf);
+	emf->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		emf, EM_TYPE_FORMAT, EMFormatPrivate);
 
 	emf->inline_table = g_hash_table_new_full (
 		g_str_hash, g_str_equal,
@@ -369,6 +368,7 @@ emf_init (EMFormat *emf)
 	g_queue_init (&emf->header_list);
 	em_format_default_headers (emf);
 	emf->part_id = g_string_new("");
+	emf->current_message_part_id = NULL;
 	emf->validity_found = 0;
 
 	shell = e_shell_get_default ();
@@ -2079,12 +2079,16 @@ emf_message_rfc822 (EMFormat *emf,
 	CamelDataWrapper *dw = camel_medium_get_content ((CamelMedium *)part);
 	const EMFormatHandler *handle;
 	gint len;
+	gchar *parent_message_part_id;
 
 	if (!CAMEL_IS_MIME_MESSAGE (dw)) {
 		em_format_format_source (emf, stream, part, cancellable);
 		return;
 	}
 
+	parent_message_part_id = emf->current_message_part_id;
+	emf->current_message_part_id = g_strdup (emf->part_id->str);
+
 	len = emf->part_id->len;
 	g_string_append_printf(emf->part_id, ".rfc822");
 
@@ -2095,6 +2099,9 @@ emf_message_rfc822 (EMFormat *emf,
 			handle, cancellable, FALSE);
 
 	g_string_truncate (emf->part_id, len);
+
+	g_free (emf->current_message_part_id);
+	emf->current_message_part_id = parent_message_part_id;
 }
 
 static void
