@@ -37,10 +37,6 @@
 
 #include "e-rule-editor.h"
 
-#define E_RULE_EDITOR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_RULE_EDITOR, ERuleEditorPrivate))
-
 static gint enable_undo = 0;
 
 enum {
@@ -70,20 +66,20 @@ rule_editor_add_undo (ERuleEditor *editor,
                       gint rank,
                       gint newrank)
 {
-        ERuleEditorUndo *undo;
+	ERuleEditorUndo *undo;
 
-        if (!editor->undo_active && enable_undo) {
-                undo = g_malloc0 (sizeof (*undo));
-                undo->rule = rule;
-                undo->type = type;
-                undo->rank = rank;
-                undo->newrank = newrank;
+	if (!editor->undo_active && enable_undo) {
+		undo = g_malloc0 (sizeof (*undo));
+		undo->rule = rule;
+		undo->type = type;
+		undo->rank = rank;
+		undo->newrank = newrank;
 
-                undo->next = editor->undo_log;
-                editor->undo_log = undo;
-        } else {
-                g_object_unref (rule);
-        }
+		undo->next = editor->undo_log;
+		editor->undo_log = undo;
+	} else {
+		g_object_unref (rule);
+	}
 }
 
 static void
@@ -263,9 +259,6 @@ rule_add (GtkWidget *widget, ERuleEditor *editor)
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OK, GTK_RESPONSE_OK,
 				NULL);
-#if !GTK_CHECK_VERSION(2,90,7)
-	g_object_set (editor->dialog, "has-separator", FALSE, NULL);
-#endif
 
 	gtk_window_set_title ((GtkWindow *) editor->dialog, _("Add Rule"));
 	gtk_window_set_default_size (GTK_WINDOW (editor->dialog), 650, 400);
@@ -352,16 +345,11 @@ rule_edit (GtkWidget *widget, ERuleEditor *editor)
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OK, GTK_RESPONSE_OK,
 				NULL);
-#if !GTK_CHECK_VERSION(2,90,7)
-	g_object_set (editor->dialog, "has-separator", FALSE, NULL);
-#endif
 
 	gtk_window_set_title ((GtkWindow *) editor->dialog, _("Edit Rule"));
 	gtk_window_set_default_size (GTK_WINDOW (editor->dialog), 650, 400);
 	gtk_window_set_resizable (GTK_WINDOW (editor->dialog), TRUE);
-	gtk_widget_set_parent_window (
-		GTK_WIDGET (editor->dialog),
-		gtk_widget_get_window (GTK_WIDGET (editor)));
+	gtk_window_set_transient_for (GTK_WINDOW (editor->dialog), GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (editor))));
 	gtk_container_set_border_width ((GtkContainer *) editor->dialog, 6);
 
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (editor->dialog));
@@ -579,8 +567,7 @@ rule_editor_dispose (GObject *object)
 	}
 
 	/* Chain up to parent's dispose() method. */
-	if (G_OBJECT_CLASS (e_rule_editor_parent_class)->dispose)
-		G_OBJECT_CLASS (e_rule_editor_parent_class)->dispose (object);
+	G_OBJECT_CLASS (e_rule_editor_parent_class)->dispose (object);
 }
 
 static void
@@ -663,7 +650,8 @@ e_rule_editor_class_init (ERuleEditorClass *class)
 static void
 e_rule_editor_init (ERuleEditor *editor)
 {
-	editor->priv = E_RULE_EDITOR_GET_PRIVATE (editor);
+	editor->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		editor, E_TYPE_RULE_EDITOR, ERuleEditorPrivate);
 }
 
 /**
@@ -819,7 +807,12 @@ e_rule_editor_construct (ERuleEditor *editor,
 	editor->list = GTK_TREE_VIEW (object);
 
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW (object), 0);
+	g_return_if_fail (column != NULL);
+
+	gtk_tree_view_column_set_visible (column, FALSE);
 	list = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (column));
+	g_return_if_fail (list != NULL);
+
 	renderer = GTK_CELL_RENDERER (list->data);
 	g_warn_if_fail (GTK_IS_CELL_RENDERER_TOGGLE (renderer));
 
@@ -850,9 +843,6 @@ e_rule_editor_construct (ERuleEditor *editor,
 		G_CALLBACK (editor_response), editor);
 	rule_editor_set_source (editor, source);
 
-#if !GTK_CHECK_VERSION(2,90,7)
-	g_object_set (editor, "has-separator", FALSE, NULL);
-#endif
 	gtk_dialog_add_buttons ((GtkDialog *) editor,
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OK, GTK_RESPONSE_OK,
