@@ -46,10 +46,6 @@
 #include "message-list.h"
 #include "e-mail-reader-utils.h"
 
-#define E_MAIL_PANED_VIEW_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MAIL_PANED_VIEW, EMailPanedViewPrivate))
-
 #define E_SHELL_WINDOW_ACTION_GROUP_MAIL(window) \
 	E_SHELL_WINDOW_ACTION_GROUP ((window), "mail")
 
@@ -128,7 +124,7 @@ mail_paned_view_message_list_built_cb (EMailView *view,
 	EShellWindow *shell_window;
 	GKeyFile *key_file;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_PANED_VIEW (view)->priv;
 
 	g_signal_handler_disconnect (
 		message_list, priv->message_list_built_id);
@@ -212,7 +208,7 @@ mail_paned_view_restore_state_cb (EShellWindow *shell_window,
 	GObject *object;
 	const gchar *key;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_PANED_VIEW (view)->priv;
 
 	/* Bind GObject properties to GConf keys. */
 
@@ -321,7 +317,7 @@ mail_paned_view_dispose (GObject *object)
 {
 	EMailPanedViewPrivate *priv;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (object);
+	priv = E_MAIL_PANED_VIEW (object)->priv;
 
 	if (priv->paned != NULL) {
 		g_object_unref (priv->paned);
@@ -404,7 +400,7 @@ mail_paned_view_get_formatter (EMailReader *reader)
 {
 	EMailPanedViewPrivate *priv;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_PANED_VIEW (reader)->priv;
 
 	return EM_FORMAT_HTML (priv->formatter);
 }
@@ -420,7 +416,7 @@ mail_paned_view_get_message_list (EMailReader *reader)
 {
 	EMailPanedViewPrivate *priv;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_PANED_VIEW (reader)->priv;
 
 	return priv->message_list;
 }
@@ -477,7 +473,7 @@ mail_paned_view_set_folder (EMailReader *reader,
 	gboolean value;
 	GError *error = NULL;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_PANED_VIEW (reader)->priv;
 
 	view = E_MAIL_VIEW (reader);
 	shell_view = e_mail_view_get_shell_view (view);
@@ -552,7 +548,7 @@ mail_paned_view_show_search_bar (EMailReader *reader)
 {
 	EMailPanedViewPrivate *priv;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (reader);
+	priv = E_MAIL_PANED_VIEW (reader)->priv;
 
 	gtk_widget_show (priv->search_bar);
 }
@@ -589,7 +585,7 @@ mail_paned_view_constructed (GObject *object)
 	GtkWidget *widget;
 	EWebView *web_view;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (object);
+	priv = E_MAIL_PANED_VIEW (object)->priv;
 	priv->formatter = em_format_html_display_new ();
 
 	view = E_MAIL_VIEW (object);
@@ -683,8 +679,8 @@ mail_paned_view_constructed (GObject *object)
 	 * set_preview_visible() method relies on it. */
 	e_mail_view_set_preview_visible (view, TRUE);
 
-	if (G_OBJECT_CLASS (e_mail_paned_view_parent_class)->constructed)
-		G_OBJECT_CLASS (e_mail_paned_view_parent_class)->constructed (object);
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_mail_paned_view_parent_class)->constructed (object);
 }
 
 static void
@@ -695,7 +691,7 @@ mail_paned_view_set_search_strings (EMailView *view,
 	ESearchBar *search_bar;
 	ESearchingTokenizer *tokenizer;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_PANED_VIEW (view)->priv;
 
 	search_bar = E_SEARCH_BAR (priv->search_bar);
 	tokenizer = e_search_bar_get_tokenizer (search_bar);
@@ -717,7 +713,7 @@ mail_paned_view_get_view_instance (EMailView *view)
 {
 	EMailPanedViewPrivate *priv;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_PANED_VIEW (view)->priv;
 
 	return priv->view_instance;
 }
@@ -742,7 +738,7 @@ mail_paned_view_update_view_instance (EMailView *view)
 	const gchar *folder_uri;
 	gchar *view_id;
 
-	priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
+	priv = E_MAIL_PANED_VIEW (view)->priv;
 
 	shell_view = e_mail_view_get_shell_view (view);
 	shell_view_class = E_SHELL_VIEW_GET_CLASS (shell_view);
@@ -780,7 +776,10 @@ mail_paned_view_update_view_instance (EMailView *view)
 
 	orientable = GTK_ORIENTABLE (view);
 	orientation = gtk_orientable_get_orientation (orientable);
-	show_vertical_view = (orientation == GTK_ORIENTATION_HORIZONTAL);
+	show_vertical_view =
+		(orientation == GTK_ORIENTATION_HORIZONTAL) &&
+		!e_shell_settings_get_boolean (
+		shell_settings, "mail-global-view-setting");
 
 	if (show_vertical_view) {
 		gchar *filename;
@@ -976,7 +975,8 @@ e_mail_paned_view_reader_init (EMailReaderInterface *interface)
 static void
 e_mail_paned_view_init (EMailPanedView *view)
 {
-	view->priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
+	view->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		view, E_TYPE_MAIL_PANED_VIEW, EMailPanedViewPrivate);
 	view->priv->enable_show_folder = FALSE;
 
 	g_signal_connect (
