@@ -1858,7 +1858,7 @@ e_cal_shell_view_update_search_filter (ECalShellView *cal_shell_view)
 
 	/* Build the category actions. */
 
-	list = e_categories_get_list ();
+	list = e_util_get_searchable_categories ();
 	for (iter = list, ii = 0; iter != NULL; iter = iter->next, ii++) {
 		const gchar *category_name = iter->data;
 		const gchar *filename;
