@@ -206,7 +206,7 @@ action_calendar_taskpad_open_url_cb (GtkAction *action,
 	/* XXX We only open the URI of the first selected task. */
 	prop = icalcomponent_get_first_property (
 		comp_data->icalcomp, ICAL_URL_PROPERTY);
-	g_return_if_fail (prop == NULL);
+	g_return_if_fail (prop != NULL);
 
 	uri = icalproperty_get_url (prop);
 	e_show_uri (GTK_WINDOW (shell_window), uri);
@@ -220,12 +220,13 @@ action_calendar_taskpad_print_cb (GtkAction *action,
 	ECalModelComponent *comp_data;
 	ETaskTable *task_table;
 	ECalComponent *comp;
+	ECalModel *model;
 	icalcomponent *clone;
-	GtkPrintOperationAction print_action;
 	GSList *list;
 
 	cal_shell_content = cal_shell_view->priv->cal_shell_content;
 	task_table = e_cal_shell_content_get_task_table (cal_shell_content);
+	model = e_task_table_get_model (task_table);
 
 	list = e_task_table_get_selected (task_table);
 	g_return_if_fail (list != NULL);
@@ -235,9 +236,14 @@ action_calendar_taskpad_print_cb (GtkAction *action,
 	/* XXX We only print the first selected task. */
 	comp = e_cal_component_new ();
 	clone = icalcomponent_new_clone (comp_data->icalcomp);
-	print_action = GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG;
 	e_cal_component_set_icalcomponent (comp, clone);
-	print_comp (comp, comp_data->client, print_action);
+
+	print_comp (
+		comp, comp_data->client,
+		e_cal_model_get_timezone (model),
+		e_cal_model_get_use_24_hour_format (model),
+		GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG);
+
 	g_object_unref (comp);
 }
 
@@ -556,7 +562,7 @@ e_cal_shell_view_taskpad_set_status_message (ECalShellView *cal_shell_view,
 
 	if (status_message == NULL || *status_message == '\0') {
 		if (activity != NULL) {
-			e_activity_complete (activity);
+			e_activity_set_state (activity, E_ACTIVITY_COMPLETED);
 			g_object_unref (activity);
 			activity = NULL;
 		}
@@ -564,12 +570,12 @@ e_cal_shell_view_taskpad_set_status_message (ECalShellView *cal_shell_view,
 	} else if (activity == NULL) {
 		activity = e_activity_new ();
 		e_activity_set_percent (activity, percent);
-		e_activity_set_primary_text (activity, status_message);
+		e_activity_set_text (activity, status_message);
 		e_shell_backend_add_activity (shell_backend, activity);
 
 	} else {
 		e_activity_set_percent (activity, percent);
-		e_activity_set_primary_text (activity, status_message);
+		e_activity_set_text (activity, status_message);
 	}
 
 	cal_shell_view->priv->taskpad_activity = activity;
