@@ -60,7 +60,10 @@ extension_set_state (EConnMan *extension, const gchar *state)
 }
 
 static void
-cm_connection_closed_cb (GDBusConnection *pconnection, gboolean remote_peer_vanished, GError *error, gpointer user_data)
+cm_connection_closed_cb (GDBusConnection *pconnection,
+                         gboolean remote_peer_vanished,
+                         GError *error,
+                         gpointer user_data)
 {
 	EConnMan *extension = user_data;
 
@@ -105,7 +108,8 @@ connman_check_initial_state (EConnMan *extension)
 
 	/* XXX Assuming this should be safe to call synchronously. */
 	response = g_dbus_connection_send_message_with_reply_sync (
-		extension->connection, message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, 100, NULL, NULL, &error);
+		extension->connection, message,
+		G_DBUS_SEND_MESSAGE_FLAGS_NONE, 100, NULL, NULL, &error);
 
 	if (response != NULL) {
 		gchar *state = NULL;
@@ -162,7 +166,9 @@ network_manager_connect (EConnMan *extension)
 		goto fail;
 	}
 
-	g_signal_connect (extension->connection, "closed", G_CALLBACK (cm_connection_closed_cb), extension);
+	g_signal_connect (
+		extension->connection, "closed",
+		G_CALLBACK (cm_connection_closed_cb), extension);
 
 	connman_check_initial_state (extension);
 
@@ -180,8 +186,8 @@ network_manager_constructed (GObject *object)
 {
 	network_manager_connect (E_CONNMAN (object));
 
-	if (G_OBJECT_CLASS (e_connman_parent_class)->constructed)
-		G_OBJECT_CLASS (e_connman_parent_class)->constructed (object);
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (e_connman_parent_class)->constructed (object);
 }
 
 static void
