@@ -25,10 +25,6 @@
 #include "mail/e-mail-sidebar.h"
 #include "mail/em-folder-utils.h"
 
-#define E_MAIL_SHELL_SIDEBAR_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_MAIL_SHELL_SIDEBAR, EMailShellSidebarPrivate))
-
 struct _EMailShellSidebarPrivate {
 	GtkWidget *folder_tree;
 };
@@ -99,7 +95,7 @@ mail_shell_sidebar_dispose (GObject *object)
 {
 	EMailShellSidebarPrivate *priv;
 
-	priv = E_MAIL_SHELL_SIDEBAR_GET_PRIVATE (object);
+	priv = E_MAIL_SHELL_SIDEBAR (object)->priv;
 
 	if (priv->folder_tree != NULL) {
 		g_object_unref (priv->folder_tree);
@@ -231,8 +227,18 @@ guess_screen_width (EMailShellSidebar *sidebar)
 }
 
 static void
-mail_shell_sidebar_size_request (GtkWidget *widget,
-                                 GtkRequisition *requisition)
+mail_shell_sidebar_get_preferred_height (GtkWidget *widget,
+                                         gint *minimum_height,
+                                         gint *natural_height)
+{
+	GTK_WIDGET_CLASS (parent_class)->get_preferred_height (
+		widget, minimum_height, natural_height);
+}
+
+static void
+mail_shell_sidebar_get_preferred_width (GtkWidget *widget,
+                                        gint *minimum_width,
+                                        gint *natural_width)
 {
 	/* We override the normal size-request handler so that we can
 	 * spit out a treeview with a suitable width.  We measure the
@@ -258,7 +264,8 @@ mail_shell_sidebar_size_request (GtkWidget *widget,
 
 	sidebar = E_MAIL_SHELL_SIDEBAR (widget);
 
-	GTK_WIDGET_CLASS (parent_class)->size_request (widget, requisition);
+	GTK_WIDGET_CLASS (parent_class)->get_preferred_width (
+		widget, minimum_width, natural_width);
 
 	/* This string is a mockup only; it doesn't need to be translated */
 	layout = gtk_widget_create_pango_layout (
@@ -274,7 +281,7 @@ mail_shell_sidebar_size_request (GtkWidget *widget,
 	border = 2 * style->xthickness + 4;
 	sidebar_width = ink_rect.width + border;
 	sidebar_width = MIN (sidebar_width, screen_width / 4);
-	requisition->width = MAX (requisition->width, sidebar_width);
+	*minimum_width = *natural_width = MAX (*natural_width, sidebar_width);
 }
 
 static guint32
@@ -283,7 +290,7 @@ mail_shell_sidebar_check_state (EShellSidebar *shell_sidebar)
 	EMailShellSidebarPrivate *priv;
 	EMailSidebar *sidebar;
 
-	priv = E_MAIL_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
+	priv = E_MAIL_SHELL_SIDEBAR (shell_sidebar)->priv;
 	sidebar = E_MAIL_SIDEBAR (priv->folder_tree);
 
 	return e_mail_sidebar_check_state (sidebar);
@@ -305,7 +312,8 @@ mail_shell_sidebar_class_init (EMailShellSidebarClass *class)
 	object_class->constructed = mail_shell_sidebar_constructed;
 
 	widget_class = GTK_WIDGET_CLASS (class);
-	widget_class->size_request = mail_shell_sidebar_size_request;
+	widget_class->get_preferred_width = mail_shell_sidebar_get_preferred_width;
+	widget_class->get_preferred_height = mail_shell_sidebar_get_preferred_height;
 
 	shell_sidebar_class = E_SHELL_SIDEBAR_CLASS (class);
 	shell_sidebar_class->check_state = mail_shell_sidebar_check_state;
@@ -324,8 +332,9 @@ mail_shell_sidebar_class_init (EMailShellSidebarClass *class)
 static void
 mail_shell_sidebar_init (EMailShellSidebar *mail_shell_sidebar)
 {
-	mail_shell_sidebar->priv =
-		E_MAIL_SHELL_SIDEBAR_GET_PRIVATE (mail_shell_sidebar);
+	mail_shell_sidebar->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		mail_shell_sidebar, E_TYPE_MAIL_SHELL_SIDEBAR,
+		EMailShellSidebarPrivate);
 
 	/* Postpone widget construction until we have a shell view. */
 }
