@@ -67,6 +67,7 @@
 
 #include <mail/e-mail-backend.h>
 #include <mail/e-mail-local.h>
+#include <mail/em-folder-selection-button.h>
 #include <mail/mail-mt.h>
 #include <mail/mail-tools.h>
 #include <mail/em-utils.h>
@@ -80,20 +81,29 @@
 #define gmtime_r(tp,tmp) (gmtime(tp)?(*(tmp)=*gmtime(tp),(tmp)):0)
 #endif
 
-gboolean org_gnome_evolution_readdbx_supported (EPlugin *epl, EImportTarget *target);
-GtkWidget *org_gnome_evolution_readdbx_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im);
-void org_gnome_evolution_readdbx_import (EImport *ei, EImportTarget *target, EImportImporter *im);
-void org_gnome_evolution_readdbx_cancel (EImport *ei, EImportTarget *target, EImportImporter *im);
-gint e_plugin_lib_enable (EPlugin *ep, gint enable);
+gboolean	org_gnome_evolution_readdbx_supported
+						(EPlugin *epl,
+						 EImportTarget *target);
+GtkWidget *	org_gnome_evolution_readdbx_getwidget
+						(EImport *ei,
+						 EImportTarget *target,
+						 EImportImporter *im);
+void		org_gnome_evolution_readdbx_import
+						(EImport *ei,
+						 EImportTarget *target,
+						 EImportImporter *im);
+void		org_gnome_evolution_readdbx_cancel
+						(EImport *ei,
+						 EImportTarget *target,
+						 EImportImporter *im);
+gint		e_plugin_lib_enable		(EPlugin *ep,
+						 gint enable);
 
-/* em-folder-selection-button.h is private, even though other internal evo plugins use it!
+/* em-folder-selection-button.h is private, even though other internal
+ * evo plugins use it!
    so declare the functions here
    TODO: sort out whether this should really be private
 */
-typedef struct _EMFolderSelectionButton        EMFolderSelectionButton;
-GtkWidget *em_folder_selection_button_new (const gchar *title, const gchar *caption);
-void        em_folder_selection_button_set_selection (EMFolderSelectionButton *button, const gchar *uri);
-const gchar *em_folder_selection_button_get_selection (EMFolderSelectionButton *button);
 
 typedef struct {
 	MailMsg base;
@@ -187,8 +197,13 @@ folder_selected (EMFolderSelectionButton *button, EImportTargetURI *target)
 }
 
 GtkWidget *
-org_gnome_evolution_readdbx_getwidget (EImport *ei, EImportTarget *target, EImportImporter *im)
+org_gnome_evolution_readdbx_getwidget (EImport *ei,
+                                       EImportTarget *target,
+                                       EImportImporter *im)
 {
+	EShell *shell;
+	EShellBackend *shell_backend;
+	EMailSession *session;
 	GtkWidget *hbox, *w;
 	GtkLabel *label;
 	gchar *select_uri = NULL;
@@ -220,7 +235,7 @@ org_gnome_evolution_readdbx_getwidget (EImport *ei, EImportTarget *target, EImpo
 	}
 #endif
 	if (!select_uri)
-		select_uri = g_strdup (e_mail_local_get_folder_uri (E_MAIL_FOLDER_INBOX));
+		select_uri = g_strdup (e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_INBOX));
 
 	hbox = gtk_hbox_new (FALSE, 0);
 
@@ -229,8 +244,14 @@ org_gnome_evolution_readdbx_getwidget (EImport *ei, EImportTarget *target, EImpo
 
 	label = GTK_LABEL (w);
 
+	shell = e_shell_get_default ();
+	shell_backend = e_shell_get_backend_by_name (shell, "mail");
+	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+
 	w = em_folder_selection_button_new (
-		_("Select folder"), _("Select folder to import OE folder into"));
+		session, _("Select folder"),
+		_("Select folder to import into"));
+
 	gtk_label_set_mnemonic_widget (label, w);
 	em_folder_selection_button_set_selection ((EMFolderSelectionButton *)w, select_uri);
 	folder_selected ((EMFolderSelectionButton *)w, (EImportTargetURI *)target);
@@ -324,7 +345,8 @@ static gboolean dbx_load_index_table (DbxImporter *m, guint32 pos, guint32 *inde
 		return FALSE;
 	}
 
-	d(printf("Index at %x: indexCount %x, anotherTablePtr %x\n", pos, tindex.indexCount, tindex.anotherTablePtr));
+	d(printf("Index at %x: indexCount %x, anotherTablePtr %x\n",
+		pos, tindex.indexCount, tindex.anotherTablePtr));
 
 	if (tindex.indexCount > 0) {
 		if (!dbx_load_index_table (m, tindex.anotherTablePtr, index_ofs))
@@ -448,7 +470,8 @@ dbx_read_mail_body (DbxImporter *m, guint32 offset, gint bodyfd)
 			buffer = g_malloc (buflen);
 		}
 		d(printf("Reading %d bytes from %lx\n", hdr.blocksize, offset + sizeof(hdr)));
-		if (dbx_pread (m->dbx_fd, buffer, hdr.blocksize, offset + sizeof (hdr)) != hdr.blocksize) {
+		if (dbx_pread (m->dbx_fd, buffer, hdr.blocksize,
+			offset + sizeof (hdr)) != hdr.blocksize) {
 			g_set_error (
 				&m->base.error,
 				CAMEL_ERROR, CAMEL_ERROR_GENERIC,
@@ -546,6 +569,7 @@ dbx_import_file (DbxImporter *m)
 	EShell *shell;
 	EShellBackend *shell_backend;
 	EMailSession *session;
+	GCancellable *cancellable;
 	gchar *filename;
 	CamelFolder *folder;
 	gint tmpfile;
@@ -553,7 +577,11 @@ dbx_import_file (DbxImporter *m)
 	gint missing = 0;
 	m->status_what = NULL;
 	filename = g_filename_from_uri (((EImportTargetURI *)m->target)->uri_src, NULL, NULL);
-	m->parent_uri = g_strdup (((EImportTargetURI *)m->target)->uri_dest); /* Destination folder, was set in our widget */
+
+	/* Destination folder, was set in our widget */
+	m->parent_uri = g_strdup (((EImportTargetURI *)m->target)->uri_dest);
+
+	cancellable = e_activity_get_cancellable (m->base.activity);
 
 	/* XXX Dig up the EMailSession from the default EShell.
 	 *     Since the EImport framework doesn't allow for user
@@ -565,7 +593,7 @@ dbx_import_file (DbxImporter *m)
 	camel_operation_push_message (NULL, _("Importing '%s'"), filename);
 	folder = e_mail_session_uri_to_folder_sync (
 		session, m->parent_uri, CAMEL_STORE_FOLDER_CREATE,
-		m->base.cancellable, &m->base.error);
+		cancellable, &m->base.error);
 	if (!folder)
 		return;
 	d(printf("importing to %s\n", camel_folder_get_full_name(folder)));
@@ -603,7 +631,7 @@ dbx_import_file (DbxImporter *m)
 		gboolean success;
 
 		camel_operation_progress (NULL, 100 * i / m->index_count);
-		camel_operation_progress (m->cancellable, 100 * i / m->index_count);
+		camel_operation_progress (cancellable, 100 * i / m->index_count);
 
 		if (!dbx_read_email (m, m->indices[i], tmpfile, &dbx_flags)) {
 			d(printf("Cannot read email index %d at %x\n",
@@ -638,7 +666,7 @@ dbx_import_file (DbxImporter *m)
 		camel_message_info_set_flags (info, flags, ~0);
 		success = camel_folder_append_message_sync (
 			folder, msg, info, NULL,
-			m->base.cancellable, &m->base.error);
+			cancellable, &m->base.error);
 		camel_message_info_free (info);
 		g_object_unref (msg);
 
@@ -667,7 +695,9 @@ dbx_import_file (DbxImporter *m)
 }
 
 static void
-dbx_import_import (DbxImporter *m)
+dbx_import_import (DbxImporter *m,
+                   GCancellable *cancellable,
+                   GError **error)
 {
 	dbx_import_file (m);
 }
@@ -716,7 +746,9 @@ dbx_status_timeout (gpointer data)
 		pc = importer->status_pc;
 		g_mutex_unlock (importer->status_lock);
 
-		e_import_status (importer->target->import, (EImportTarget *)importer->target, what, pc);
+		e_import_status (
+			importer->target->import,
+			(EImportTarget *) importer->target, what, pc);
 	}
 
 	return TRUE;
@@ -736,10 +768,11 @@ dbx_status (CamelOperation *op, const gchar *what, gint pc, gpointer data)
 
 /* Start the main import operation */
 void
-org_gnome_evolution_readdbx_import (EImport *ei, EImportTarget *target, EImportImporter *im)
+org_gnome_evolution_readdbx_import (EImport *ei,
+                                    EImportTarget *target,
+                                    EImportImporter *im)
 {
 	DbxImporter *m;
-	gint id;
 
 	m = mail_msg_new (&dbx_import_info);
 	g_datalist_set_data (&target->data, "dbx-msg", m);
@@ -760,13 +793,13 @@ org_gnome_evolution_readdbx_import (EImport *ei, EImportTarget *target, EImportI
 		m->cancellable, "status",
 		G_CALLBACK (dbx_status), m);
 
-	id = m->base.seq;
-
 	mail_msg_unordered_push (m);
 }
 
 void
-org_gnome_evolution_readdbx_cancel (EImport *ei, EImportTarget *target, EImportImporter *im)
+org_gnome_evolution_readdbx_cancel (EImport *ei,
+                                    EImportTarget *target,
+                                    EImportImporter *im)
 {
 	DbxImporter *m = g_datalist_get_data (&target->data, "dbx-msg");
 
