@@ -52,9 +52,6 @@
 #include "e-tree.h"
 #include "e-tree-table-adapter.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define COLUMN_HEADER_HEIGHT 16
 
 #define d(x)
@@ -97,7 +94,11 @@ enum {
 	PROP_DRAW_FOCUS,
 	PROP_ETTA,
 	PROP_UNIFORM_ROW_HEIGHT,
-	PROP_ALWAYS_SEARCH
+	PROP_ALWAYS_SEARCH,
+	PROP_HADJUSTMENT,
+	PROP_VADJUSTMENT,
+	PROP_HSCROLL_POLICY,
+	PROP_VSCROLL_POLICY
 };
 
 enum {
@@ -107,7 +108,7 @@ enum {
 	ET_SCROLL_RIGHT = 1 << 3
 };
 
-struct ETreePriv {
+struct _ETreePrivate {
 	ETreeModel *model;
 	ETreeTableAdapter *etta;
 
@@ -247,7 +248,8 @@ static void hover_off (ETree *et);
 static void hover_on (ETree *et, gint x, gint y);
 static void context_destroyed (gpointer data, GObject *ctx);
 
-G_DEFINE_TYPE (ETree, e_tree, GTK_TYPE_TABLE)
+G_DEFINE_TYPE_WITH_CODE (ETree, e_tree, GTK_TYPE_TABLE,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL))
 
 static void
 et_disconnect_from_etta (ETree *et)
@@ -379,70 +381,94 @@ connect_header (ETree *e_tree, ETableState *state)
 static void
 et_dispose (GObject *object)
 {
-	ETree *et = E_TREE (object);
+	ETreePrivate *priv;
 
-	if (et->priv) {
+	priv = E_TREE (object)->priv;
 
-		if (et->priv->search) {
-			if (et->priv->search_search_id)
-				g_signal_handler_disconnect (et->priv->search,
-							     et->priv->search_search_id);
-			if (et->priv->search_accept_id)
-				g_signal_handler_disconnect (et->priv->search,
-							     et->priv->search_accept_id);
-			g_object_unref (et->priv->search);
-		}
-
-		if (et->priv->reflow_idle_id)
-			g_source_remove (et->priv->reflow_idle_id);
-		et->priv->reflow_idle_id = 0;
-
-		scroll_off (et);
-		hover_off (et);
-		g_list_foreach (
-			et->priv->expanded_list,
-			(GFunc) g_free, NULL);
-		g_list_free (et->priv->expanded_list);
-
-		et_disconnect_from_etta (et);
-
-		g_object_unref (et->priv->etta);
-		g_object_unref (et->priv->model);
-		g_object_unref (et->priv->full_header);
-		disconnect_header (et);
-		g_object_unref (et->priv->selection);
-		if (et->priv->spec)
-			g_object_unref (et->priv->spec);
-		et->priv->spec = NULL;
-
-		if (et->priv->sorter)
-			g_object_unref (et->priv->sorter);
-		et->priv->sorter = NULL;
-
-		if (et->priv->header_canvas)
-			gtk_widget_destroy (GTK_WIDGET (et->priv->header_canvas));
-		et->priv->header_canvas = NULL;
-
-		if (et->priv->site)
-			e_tree_drag_source_unset (et);
-
-		if (et->priv->last_drop_context)
-			g_object_weak_unref (G_OBJECT (et->priv->last_drop_context), context_destroyed, et);
-		et->priv->last_drop_context = NULL;
-
-		if (et->priv->info_text)
-			g_object_run_dispose (G_OBJECT (et->priv->info_text));
-		et->priv->info_text = NULL;
-		et->priv->info_text_resize_id = 0;
-
-		gtk_widget_destroy (GTK_WIDGET (et->priv->table_canvas));
-
-		g_free (et->priv);
-		et->priv = NULL;
+	if (priv->search != NULL) {
+		g_signal_handler_disconnect (
+			priv->search, priv->search_search_id);
+		g_signal_handler_disconnect (
+			priv->search, priv->search_accept_id);
+		g_object_unref (priv->search);
+		priv->search = NULL;
 	}
 
-	if (G_OBJECT_CLASS (e_tree_parent_class)->dispose)
-		G_OBJECT_CLASS (e_tree_parent_class)->dispose (object);
+	if (priv->reflow_idle_id > 0) {
+		g_source_remove (priv->reflow_idle_id);
+		priv->reflow_idle_id = 0;
+	}
+
+	scroll_off (E_TREE (object));
+	hover_off (E_TREE (object));
+	g_list_foreach (
+		priv->expanded_list,
+		(GFunc) g_free, NULL);
+	g_list_free (priv->expanded_list);
+	priv->expanded_list = NULL;
+
+	et_disconnect_from_etta (E_TREE (object));
+
+	if (priv->etta != NULL) {
+		g_object_unref (priv->etta);
+		priv->etta = NULL;
+	}
+
+	if (priv->model != NULL) {
+		g_object_unref (priv->model);
+		priv->model = NULL;
+	}
+
+	if (priv->full_header != NULL) {
+		g_object_unref (priv->full_header);
+		priv->full_header = NULL;
+	}
+
+	disconnect_header (E_TREE (object));
+
+	if (priv->selection != NULL) {
+		g_object_unref (priv->selection);
+		priv->selection = NULL;
+	}
+
+	if (priv->spec != NULL) {
+		g_object_unref (priv->spec);
+		priv->spec = NULL;
+	}
+
+	if (priv->sorter != NULL) {
+		g_object_unref (priv->sorter);
+		priv->sorter = NULL;
+	}
+
+	if (priv->header_canvas != NULL) {
+		gtk_widget_destroy (GTK_WIDGET (priv->header_canvas));
+		priv->header_canvas = NULL;
+	}
+
+	if (priv->site)
+		e_tree_drag_source_unset (E_TREE (object));
+
+	if (priv->last_drop_context != NULL) {
+		g_object_weak_unref (
+			G_OBJECT (priv->last_drop_context),
+			context_destroyed, object);
+		priv->last_drop_context = NULL;
+	}
+
+	if (priv->info_text != NULL) {
+		g_object_run_dispose (G_OBJECT (priv->info_text));
+		priv->info_text = NULL;
+	}
+	priv->info_text_resize_id = 0;
+
+	if (priv->table_canvas != NULL) {
+		gtk_widget_destroy (GTK_WIDGET (priv->table_canvas));
+		priv->table_canvas = NULL;
+	}
+
+	/* Chain up to parent's dispose() method. */
+	G_OBJECT_CLASS (e_tree_parent_class)->dispose (object);
 }
 
 static void
@@ -555,65 +581,21 @@ e_tree_init (ETree *e_tree)
 
 	gtk_table_set_homogeneous (GTK_TABLE (e_tree), FALSE);
 
-	e_tree->priv                         = g_new (ETreePriv, 1);
-
-	e_tree->priv->model                  = NULL;
-	e_tree->priv->etta                   = NULL;
-
-	e_tree->priv->full_header            = NULL;
-	e_tree->priv->header                 = NULL;
-
-	e_tree->priv->structure_change_id    = 0;
-	e_tree->priv->expansion_change_id    = 0;
-	e_tree->priv->sort_info_change_id    = 0;
-	e_tree->priv->group_info_change_id   = 0;
-
-	e_tree->priv->sort_info              = NULL;
-	e_tree->priv->sorter                 = NULL;
-	e_tree->priv->reflow_idle_id         = 0;
-	e_tree->priv->scroll_idle_id         = 0;
-	e_tree->priv->hover_idle_id          = 0;
-
-	e_tree->priv->show_cursor_after_reflow = FALSE;
-
-	e_tree->priv->table_model_change_id  = 0;
-	e_tree->priv->table_row_change_id    = 0;
-	e_tree->priv->table_cell_change_id   = 0;
-	e_tree->priv->table_rows_delete_id   = 0;
+	e_tree->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		e_tree, E_TYPE_TREE, ETreePrivate);
 
 	e_tree->priv->alternating_row_colors = 1;
-	e_tree->priv->horizontal_draw_grid   = 1;
-	e_tree->priv->vertical_draw_grid     = 1;
-	e_tree->priv->draw_focus             = 1;
-	e_tree->priv->cursor_mode            = E_CURSOR_SIMPLE;
-	e_tree->priv->length_threshold       = 200;
-	e_tree->priv->uniform_row_height     = FALSE;
+	e_tree->priv->horizontal_draw_grid = 1;
+	e_tree->priv->vertical_draw_grid = 1;
+	e_tree->priv->draw_focus = 1;
+	e_tree->priv->cursor_mode = E_CURSOR_SIMPLE;
+	e_tree->priv->length_threshold = 200;
 
-	e_tree->priv->row_selection_active   = FALSE;
-	e_tree->priv->horizontal_scrolling   = FALSE;
-	e_tree->priv->scroll_direction       = 0;
+	e_tree->priv->drop_row = -1;
+	e_tree->priv->drop_col = -1;
 
-	e_tree->priv->drop_row               = -1;
-	e_tree->priv->drop_path              = NULL;
-	e_tree->priv->drop_col               = -1;
-	e_tree->priv->drop_highlight         = NULL;
-
-	e_tree->priv->last_drop_x            = 0;
-	e_tree->priv->last_drop_y            = 0;
-	e_tree->priv->last_drop_time         = 0;
-	e_tree->priv->last_drop_context      = NULL;
-
-	e_tree->priv->hover_x                = 0;
-	e_tree->priv->hover_y                = 0;
-
-	e_tree->priv->drag_row               = -1;
-	e_tree->priv->drag_path              = NULL;
-	e_tree->priv->drag_col               = -1;
-
-	e_tree->priv->expanded_list          = NULL;
-
-	e_tree->priv->site                   = NULL;
-	e_tree->priv->do_drag                = FALSE;
+	e_tree->priv->drag_row = -1;
+	e_tree->priv->drag_col = -1;
 
 #ifdef E_TREE_USE_TREE_SELECTION
 	e_tree->priv->selection =
@@ -622,32 +604,17 @@ e_tree_init (ETree *e_tree)
 	e_tree->priv->selection =
 		E_SELECTION_MODEL (e_table_selection_model_new ());
 #endif
-	e_tree->priv->spec                   = NULL;
 
-	e_tree->priv->info_text              = NULL;
-	e_tree->priv->info_text_resize_id    = 0;
+	e_tree->priv->search = e_table_search_new ();
 
-	e_tree->priv->header_canvas          = NULL;
-	e_tree->priv->table_canvas           = NULL;
-
-	e_tree->priv->header_item            = NULL;
-	e_tree->priv->root                   = NULL;
-
-	e_tree->priv->white_item             = NULL;
-	e_tree->priv->item                   = NULL;
-
-	e_tree->priv->search                 = e_table_search_new ();
-
-	e_tree->priv->search_search_id       =
+	e_tree->priv->search_search_id =
 		g_signal_connect (G_OBJECT (e_tree->priv->search), "search",
-				  G_CALLBACK (et_search_search), e_tree);
-	e_tree->priv->search_accept_id       =
+				 G_CALLBACK (et_search_search), e_tree);
+	e_tree->priv->search_accept_id =
 		g_signal_connect (G_OBJECT (e_tree->priv->search), "accept",
-				  G_CALLBACK (et_search_accept), e_tree);
+				 G_CALLBACK (et_search_accept), e_tree);
 
-	e_tree->priv->current_search_col     = NULL;
-	e_tree->priv->search_col_set         = FALSE;
-	e_tree->priv->always_search          = g_getenv ("GAL_ALWAYS_SEARCH") ? TRUE : FALSE;
+	e_tree->priv->always_search = g_getenv ("GAL_ALWAYS_SEARCH") ? TRUE : FALSE;
 }
 
 /* Grab_focus handler for the ETree */
@@ -759,7 +726,7 @@ scroll_to_cursor (ETree *e_tree)
 {
 	ETreePath path;
 	GtkAdjustment *adjustment;
-	GtkLayout *layout;
+	GtkScrollable *scrollable;
 	gint x, y, w, h;
 	gdouble page_size;
 	gdouble lower;
@@ -779,8 +746,8 @@ scroll_to_cursor (ETree *e_tree)
 				&row, &col, &x, &y, &w, &h);
 	}
 
-	layout = GTK_LAYOUT (e_tree->priv->table_canvas);
-	adjustment = gtk_layout_get_vadjustment (layout);
+	scrollable = GTK_SCROLLABLE (e_tree->priv->table_canvas);
+	adjustment = gtk_scrollable_get_vadjustment (scrollable);
 
 	page_size = gtk_adjustment_get_page_size (adjustment);
 	lower = gtk_adjustment_get_lower (adjustment);
@@ -928,13 +895,13 @@ item_key_press (ETableItem *eti, gint row, gint col, GdkEvent *event, ETree *et)
 	ETreePath path;
 	gint y, row_local, col_local;
 	GtkAdjustment *adjustment;
-	GtkLayout *layout;
+	GtkScrollable *scrollable;
 	gdouble page_size;
 	gdouble upper;
 	gdouble value;
 
-	layout = GTK_LAYOUT (et->priv->table_canvas);
-	adjustment = gtk_layout_get_vadjustment (layout);
+	scrollable = GTK_SCROLLABLE (et->priv->table_canvas);
+	adjustment = gtk_scrollable_get_vadjustment (scrollable);
 
 	page_size = gtk_adjustment_get_page_size (adjustment);
 	upper = gtk_adjustment_get_upper (adjustment);
@@ -1514,7 +1481,7 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 		   ETableSpecification *specification, ETableState *state)
 {
 	GtkAdjustment *adjustment;
-	GtkLayout *layout;
+	GtkScrollable *scrollable;
 	gint row = 0;
 
 	if (ete)
@@ -1566,12 +1533,12 @@ et_real_construct (ETree *e_tree, ETreeModel *etm, ETableExtras *ete,
 	}
 	e_tree_setup_table (e_tree);
 
-	layout = GTK_LAYOUT (e_tree->priv->table_canvas);
+	scrollable = GTK_SCROLLABLE (e_tree->priv->table_canvas);
 
-	adjustment = gtk_layout_get_vadjustment (layout);
+	adjustment = gtk_scrollable_get_vadjustment (scrollable);
 	gtk_adjustment_set_step_increment (adjustment, 20);
 
-	adjustment = gtk_layout_get_hadjustment (layout);
+	adjustment = gtk_scrollable_get_hadjustment (scrollable);
 	gtk_adjustment_set_step_increment (adjustment, 20);
 
 	if (!specification->no_headers) {
@@ -1747,7 +1714,7 @@ e_tree_new (ETreeModel *etm, ETableExtras *ete, const gchar *spec, const gchar *
 	g_return_val_if_fail (ete == NULL || E_IS_TABLE_EXTRAS (ete), NULL);
 	g_return_val_if_fail (spec != NULL, NULL);
 
-	e_tree = g_object_new (E_TREE_TYPE, NULL);
+	e_tree = g_object_new (E_TYPE_TREE, NULL);
 
 	if (!e_tree_construct (e_tree, etm, ete, spec, state)) {
 		g_object_unref (e_tree);
@@ -1790,7 +1757,7 @@ e_tree_new_from_spec_file (ETreeModel *etm,
 	g_return_val_if_fail (ete == NULL || E_IS_TABLE_EXTRAS (ete), NULL);
 	g_return_val_if_fail (spec_fn != NULL, NULL);
 
-	e_tree = g_object_new (E_TREE_TYPE, NULL);
+	e_tree = g_object_new (E_TYPE_TREE, NULL);
 
 	if (!e_tree_construct_from_spec_file (e_tree, etm, ete, spec_fn, state_fn)) {
 		g_object_unref (e_tree);
@@ -1950,6 +1917,38 @@ et_get_property (GObject *object,
 	case PROP_ALWAYS_SEARCH:
 		g_value_set_boolean (value, etree->priv->always_search);
 		break;
+	case PROP_HADJUSTMENT:
+		if (etree->priv->table_canvas)
+			g_object_get_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"hadjustment", value);
+		else
+			g_value_set_object (value, NULL);
+		break;
+	case PROP_VADJUSTMENT:
+		if (etree->priv->table_canvas)
+			g_object_get_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"vadjustment", value);
+		else
+			g_value_set_object (value, NULL);
+		break;
+	case PROP_HSCROLL_POLICY:
+		if (etree->priv->table_canvas)
+			g_object_get_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"hscroll-policy", value);
+		else
+			g_value_set_enum (value, 0);
+		break;
+	case PROP_VSCROLL_POLICY:
+		if (etree->priv->table_canvas)
+			g_object_get_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"vscroll-policy", value);
+		else
+			g_value_set_enum (value, 0);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -2021,32 +2020,31 @@ et_set_property (GObject *object,
 		etree->priv->always_search = g_value_get_boolean (value);
 		clear_current_search_col (etree);
 		break;
-	}
-}
 
-static void
-set_scroll_adjustments   (ETree *tree,
-			  GtkAdjustment *hadjustment,
-			  GtkAdjustment *vadjustment)
-{
-	if (vadjustment != NULL)
-		gtk_adjustment_set_step_increment (vadjustment, 20);
-
-	if (hadjustment != NULL)
-		gtk_adjustment_set_step_increment (hadjustment, 20);
-
-	if (tree->priv) {
-		GtkLayout *layout;
-
-		layout = GTK_LAYOUT (tree->priv->table_canvas);
-
-		gtk_layout_set_hadjustment (layout, hadjustment);
-		gtk_layout_set_vadjustment (layout, vadjustment);
-
-		if (tree->priv->header_canvas != NULL)
-			gtk_layout_set_hadjustment (
-				GTK_LAYOUT (tree->priv->header_canvas),
-				hadjustment);
+	case PROP_HADJUSTMENT:
+		if (etree->priv->table_canvas)
+			g_object_set_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"hadjustment", value);
+		break;
+	case PROP_VADJUSTMENT:
+		if (etree->priv->table_canvas)
+			g_object_set_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"vadjustment", value);
+		break;
+	case PROP_HSCROLL_POLICY:
+		if (etree->priv->table_canvas)
+			g_object_set_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"hscroll-policy", value);
+		break;
+	case PROP_VSCROLL_POLICY:
+		if (etree->priv->table_canvas)
+			g_object_set_property (
+				G_OBJECT (etree->priv->table_canvas),
+				"vscroll-policy", value);
+		break;
 	}
 }
 
@@ -2388,9 +2386,7 @@ struct _ETreeDragSourceSite
 	GdkModifierType    start_button_mask;
 	GtkTargetList     *target_list;        /* Targets for drag data */
 	GdkDragAction      actions;            /* Possible actions */
-	GdkColormap       *colormap;		 /* Colormap for drag icon */
-	GdkPixmap         *pixmap;             /* Icon for drag data */
-	GdkBitmap         *mask;
+	GdkPixbuf         *pixbuf;             /* Icon for drag data */
 
 	/* Stored button press information to detect drag beginning */
 	gint               state;
@@ -2485,16 +2481,16 @@ e_tree_drag_highlight (ETree *tree,
 		       gint     row,
 		       gint     col)
 {
-	GtkAdjustment *adjustment;
 	GtkAllocation allocation;
-	GtkLayout *layout;
+	GtkAdjustment *adjustment;
+	GtkScrollable *scrollable;
 	GtkStyle *style;
 
 	g_return_if_fail (E_IS_TREE (tree));
 
-	layout = GTK_LAYOUT (tree->priv->table_canvas);
+	scrollable = GTK_SCROLLABLE (tree->priv->table_canvas);
 	style = gtk_widget_get_style (GTK_WIDGET (tree));
-	gtk_widget_get_allocation (GTK_WIDGET (layout), &allocation);
+	gtk_widget_get_allocation (GTK_WIDGET (scrollable), &allocation);
 
 	if (row != -1) {
 		gint x, y, width, height;
@@ -2504,11 +2500,11 @@ e_tree_drag_highlight (ETree *tree,
 			width = allocation.width;
 		} else {
 			e_tree_get_cell_geometry (tree, row, col, &x, &y, &width, &height);
-			adjustment = gtk_layout_get_hadjustment (layout);
+			adjustment = gtk_scrollable_get_hadjustment (scrollable);
 			x += gtk_adjustment_get_value (adjustment);
 		}
 
-		adjustment = gtk_layout_get_vadjustment (layout);
+		adjustment = gtk_scrollable_get_vadjustment (scrollable);
 		y += gtk_adjustment_get_value (adjustment);
 
 		if (tree->priv->drop_highlight == NULL) {
@@ -2611,11 +2607,10 @@ et_real_start_drag (ETree *tree, gint row, ETreePath path, gint col, GdkEvent *e
 			info = g_dataset_get_data (context, "gtk-info");
 
 			if (info && !info->icon_window) {
-				if (site->pixmap)
-					gtk_drag_set_icon_pixmap (context,
-								  site->colormap,
-								  site->pixmap,
-								  site->mask, -2, -2);
+				if (site->pixbuf)
+					gtk_drag_set_icon_pixbuf (context,
+								  site->pixbuf,
+								  -2, -2);
 				else
 					gtk_drag_set_icon_default (context);
 			}
@@ -2731,7 +2726,7 @@ e_tree_get_cell_at (ETree *tree,
 		     gint *row_return, gint *col_return)
 {
 	GtkAdjustment *adjustment;
-	GtkLayout *layout;
+	GtkScrollable *scrollable;
 
 	g_return_if_fail (E_IS_TREE (tree));
 	g_return_if_fail (row_return != NULL);
@@ -2745,12 +2740,12 @@ e_tree_get_cell_at (ETree *tree,
 	if (col_return)
 		*col_return = -1;
 
-	layout = GTK_LAYOUT (tree->priv->table_canvas);
+	scrollable = GTK_SCROLLABLE (tree->priv->table_canvas);
 
-	adjustment = gtk_layout_get_hadjustment (layout);
+	adjustment = gtk_scrollable_get_hadjustment (scrollable);
 	x += gtk_adjustment_get_value (adjustment);
 
-	adjustment = gtk_layout_get_vadjustment (layout);
+	adjustment = gtk_scrollable_get_vadjustment (scrollable);
 	y += gtk_adjustment_get_value (adjustment);
 
 	e_table_item_compute_location (
@@ -2779,7 +2774,7 @@ e_tree_get_cell_geometry (ETree *tree,
 			  gint *width_return, gint *height_return)
 {
 	GtkAdjustment *adjustment;
-	GtkLayout *layout;
+	GtkScrollable *scrollable;
 
 	g_return_if_fail (E_IS_TREE (tree));
 	g_return_if_fail (row >= 0);
@@ -2793,15 +2788,15 @@ e_tree_get_cell_geometry (ETree *tree,
 		&row, &col, x_return, y_return,
 		width_return, height_return);
 
-	layout = GTK_LAYOUT (tree->priv->table_canvas);
+	scrollable = GTK_SCROLLABLE (tree->priv->table_canvas);
 
 	if (x_return) {
-		adjustment = gtk_layout_get_hadjustment (layout);
+		adjustment = gtk_scrollable_get_hadjustment (scrollable);
 		(*x_return) -= gtk_adjustment_get_value (adjustment);
 	}
 
 	if (y_return) {
-		adjustment = gtk_layout_get_vadjustment (layout);
+		adjustment = gtk_scrollable_get_vadjustment (scrollable);
 		(*y_return) -= gtk_adjustment_get_value (adjustment);
 	}
 }
@@ -2915,7 +2910,7 @@ scroll_timeout (gpointer data)
 	ETree *et = data;
 	gint dx = 0, dy = 0;
 	GtkAdjustment *adjustment;
-	GtkLayout *layout;
+	GtkScrollable *scrollable;
 	gdouble old_h_value;
 	gdouble new_h_value;
 	gdouble old_v_value;
@@ -2934,9 +2929,9 @@ scroll_timeout (gpointer data)
 	if (et->priv->scroll_direction & ET_SCROLL_LEFT)
 		dx -= 20;
 
-	layout = GTK_LAYOUT (et->priv->table_canvas);
+	scrollable = GTK_SCROLLABLE (et->priv->table_canvas);
 
-	adjustment = gtk_layout_get_hadjustment (layout);
+	adjustment = gtk_scrollable_get_hadjustment (scrollable);
 
 	page_size = gtk_adjustment_get_page_size (adjustment);
 	lower = gtk_adjustment_get_lower (adjustment);
@@ -2947,7 +2942,7 @@ scroll_timeout (gpointer data)
 
 	gtk_adjustment_set_value (adjustment, new_h_value);
 
-	adjustment = gtk_layout_get_vadjustment (layout);
+	adjustment = gtk_scrollable_get_vadjustment (scrollable);
 
 	page_size = gtk_adjustment_get_page_size (adjustment);
 	lower = gtk_adjustment_get_lower (adjustment);
@@ -3276,38 +3271,20 @@ e_tree_class_init (ETreeClass *class)
 	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 
-	object_class                   = (GObjectClass *) class;
-	widget_class                   = (GtkWidgetClass *) class;
+	g_type_class_add_private (class, sizeof (ETreePrivate));
 
-	object_class->dispose          = et_dispose;
-	object_class->set_property     = et_set_property;
-	object_class->get_property     = et_get_property;
+	object_class = G_OBJECT_CLASS (class);
+	object_class->dispose = et_dispose;
+	object_class->set_property = et_set_property;
+	object_class->get_property = et_get_property;
 
-	widget_class->grab_focus       = et_grab_focus;
-	widget_class->unrealize        = et_unrealize;
-	widget_class->style_set        = et_canvas_style_set;
-	widget_class->focus            = et_focus;
+	widget_class = GTK_WIDGET_CLASS (class);
+	widget_class->grab_focus = et_grab_focus;
+	widget_class->unrealize = et_unrealize;
+	widget_class->style_set = et_canvas_style_set;
+	widget_class->focus = et_focus;
 
-	class->cursor_change           = NULL;
-	class->cursor_activated        = NULL;
-	class->selection_change        = NULL;
-	class->double_click            = NULL;
-	class->right_click             = NULL;
-	class->click                   = NULL;
-	class->key_press               = NULL;
-	class->start_drag              = et_real_start_drag;
-	class->state_change            = NULL;
-	class->white_space_event       = NULL;
-
-	class->tree_drag_begin         = NULL;
-	class->tree_drag_end           = NULL;
-	class->tree_drag_data_get      = NULL;
-	class->tree_drag_data_delete   = NULL;
-
-	class->tree_drag_leave         = NULL;
-	class->tree_drag_motion        = NULL;
-	class->tree_drag_drop          = NULL;
-	class->tree_drag_data_received = NULL;
+	class->start_drag = et_real_start_drag;
 
 	et_signals[CURSOR_CHANGE] =
 		g_signal_new ("cursor_change",
@@ -3343,8 +3320,11 @@ e_tree_class_init (ETreeClass *class)
 			      G_STRUCT_OFFSET (ETreeClass, double_click),
 			      NULL, NULL,
 			      e_marshal_NONE__INT_POINTER_INT_BOXED,
-			      G_TYPE_NONE, 4, G_TYPE_INT,
-			      G_TYPE_POINTER, G_TYPE_INT, GDK_TYPE_EVENT);
+			      G_TYPE_NONE, 4,
+			      G_TYPE_INT,
+			      G_TYPE_POINTER,
+			      G_TYPE_INT,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	et_signals[RIGHT_CLICK] =
 		g_signal_new ("right_click",
@@ -3353,8 +3333,11 @@ e_tree_class_init (ETreeClass *class)
 			      G_STRUCT_OFFSET (ETreeClass, right_click),
 			      g_signal_accumulator_true_handled, NULL,
 			      e_marshal_BOOLEAN__INT_POINTER_INT_BOXED,
-			      G_TYPE_BOOLEAN, 4, G_TYPE_INT, G_TYPE_POINTER,
-			      G_TYPE_INT, GDK_TYPE_EVENT);
+			      G_TYPE_BOOLEAN, 4,
+			      G_TYPE_INT,
+			      G_TYPE_POINTER,
+			      G_TYPE_INT,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	et_signals[CLICK] =
 		g_signal_new ("click",
@@ -3363,8 +3346,11 @@ e_tree_class_init (ETreeClass *class)
 			      G_STRUCT_OFFSET (ETreeClass, click),
 			      g_signal_accumulator_true_handled, NULL,
 			      e_marshal_BOOLEAN__INT_POINTER_INT_BOXED,
-			      G_TYPE_BOOLEAN, 4, G_TYPE_INT, G_TYPE_POINTER,
-			      G_TYPE_INT, GDK_TYPE_EVENT);
+			      G_TYPE_BOOLEAN, 4,
+			      G_TYPE_INT,
+			      G_TYPE_POINTER,
+			      G_TYPE_INT,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	et_signals[KEY_PRESS] =
 		g_signal_new ("key_press",
@@ -3373,8 +3359,11 @@ e_tree_class_init (ETreeClass *class)
 			      G_STRUCT_OFFSET (ETreeClass, key_press),
 			      g_signal_accumulator_true_handled, NULL,
 			      e_marshal_BOOLEAN__INT_POINTER_INT_BOXED,
-			      G_TYPE_BOOLEAN, 4, G_TYPE_INT, G_TYPE_POINTER,
-			      G_TYPE_INT, GDK_TYPE_EVENT);
+			      G_TYPE_BOOLEAN, 4,
+			      G_TYPE_INT,
+			      G_TYPE_POINTER,
+			      G_TYPE_INT,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	et_signals[START_DRAG] =
 		g_signal_new ("start_drag",
@@ -3383,8 +3372,11 @@ e_tree_class_init (ETreeClass *class)
 			      G_STRUCT_OFFSET (ETreeClass, start_drag),
 			      NULL, NULL,
 			      e_marshal_NONE__INT_POINTER_INT_BOXED,
-			      G_TYPE_NONE, 4, G_TYPE_INT, G_TYPE_POINTER,
-			      G_TYPE_INT, GDK_TYPE_EVENT);
+			      G_TYPE_NONE, 4,
+			      G_TYPE_INT,
+			      G_TYPE_POINTER,
+			      G_TYPE_INT,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	et_signals[STATE_CHANGE] =
 		g_signal_new ("state_change",
@@ -3402,7 +3394,8 @@ e_tree_class_init (ETreeClass *class)
 			      G_STRUCT_OFFSET (ETreeClass, white_space_event),
 			      g_signal_accumulator_true_handled, NULL,
 			      e_marshal_BOOLEAN__POINTER,
-			      G_TYPE_BOOLEAN, 1, GDK_TYPE_EVENT);
+			      G_TYPE_BOOLEAN, 1,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	et_signals[TREE_DRAG_BEGIN] =
 		g_signal_new ("tree_drag_begin",
@@ -3517,18 +3510,6 @@ e_tree_class_init (ETreeClass *class)
 			      G_TYPE_UINT,
 			      G_TYPE_UINT);
 
-	class->set_scroll_adjustments = set_scroll_adjustments;
-
-	widget_class->set_scroll_adjustments_signal =
-		g_signal_new ("set_scroll_adjustments",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeClass, set_scroll_adjustments),
-			      NULL, NULL,
-			      e_marshal_NONE__OBJECT_OBJECT,
-			      G_TYPE_NONE, 2, GTK_TYPE_ADJUSTMENT,
-			      GTK_TYPE_ADJUSTMENT);
-
 	g_object_class_install_property (object_class, PROP_LENGTH_THRESHOLD,
 					 g_param_spec_int ("length_threshold",
 							   "Length Threshold",
@@ -3558,7 +3539,7 @@ e_tree_class_init (ETreeClass *class)
 					 g_param_spec_object ("ETreeTableAdapter",
 							      "ETree table adapter",
 							      "ETree table adapter",
-							      E_TREE_TABLE_ADAPTER_TYPE,
+							      E_TYPE_TREE_TABLE_ADAPTER,
 							      G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class, PROP_UNIFORM_ROW_HEIGHT,
@@ -3584,6 +3565,27 @@ e_tree_class_init (ETreeClass *class)
 					     10,
 					     G_PARAM_READABLE));
 
+	gtk_widget_class_install_style_property (
+		widget_class,
+		g_param_spec_int (
+			"vertical-spacing",
+			"Vertical Row Spacing",
+			"Vertical space between rows. "
+			"It is added to top and to bottom of a row",
+			0, G_MAXINT, 3,
+			G_PARAM_READABLE |
+			G_PARAM_STATIC_STRINGS));
+
+	/* Scrollable interface */
+	g_object_class_override_property (
+		object_class, PROP_HADJUSTMENT, "hadjustment");
+	g_object_class_override_property (
+		object_class, PROP_VADJUSTMENT, "vadjustment");
+	g_object_class_override_property (
+		object_class, PROP_HSCROLL_POLICY, "hscroll-policy");
+	g_object_class_override_property (
+		object_class, PROP_VSCROLL_POLICY, "vscroll-policy");
+
 	gal_a11y_e_tree_init ();
 }
 
